package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.34.0 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.34.0) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@("`0`````````````#`!8````!````````(R``````````0```````
M`,&```````!``#@`"0!``!H`&0````8````$`````````$``````````0```
M``````!``````````?@````````!^``````````(`````P````0````````"
M.`````````(X`````````C@`````````#P`````````/``````````$````!
M````!0```````````````````````````````````````*3H````````I.@`
M```````0``````$````&````````L`````````"P`````````+``````````
M$(`````````@L````````!```````@````8```````"P(````````+`@````
M````L"`````````!T`````````'0``````````@````$````!`````````)(
M`````````D@````````"2`````````!$`````````$0`````````!&1TY5``
M```$````````GA0```````">%````````)X4`````````.P`````````[```
M```````$9'3E40````8`````````````````````````````````````````
M`````````````````````!!D=.52````!````````+``````````L```````
M``"P`````````!``````````$````````````2]L:6(O;&0V-"YS;RXQ````
M```$````%`````-'3E4`4<C!JL'JM^T%-T?8/KRUYA6[\M0````$````$```
M``%'3E4```````````,````"```````````````1````10````0````(A`1`
M!0`0$""$`(:`!``"*`@$(`D```F""`(`ND40H(@`````````10```$@```!+
M````3````%,```!4````50```%<```!8````6@```%L```!<````70```%\`
M`````````!_?Q6XM1][.?)I_:[:;Q2Y\U&34#N3_(1Q8<=D!QD?B;XL!LL#C
M2ZR'U_I"+#_EPGR2X[I@;*'[UD,):V;,KV?LU45"TW`'B9[B%`WMVV(RGN/-
MV\PEC!4+ESH-FYRI?PH"I^!0GAIK2?O@HP``````````````````````````
M```````````#```+````````&8```````````````Y$2````````````````
M`````````````-P2`````````````````````````````KT1````````````
M`````````````````EP2`````````````````````````````(,2````````
M`````````````````````-$1`````````````````````````````C\2````
M`````````````````````````542`````````````````````````````<H2
M`````````````````````````````/(2````````````````````````````
M`;<2`````````````````````````````A42````````````````````````
M``````$@`````````````````````````````6P2````````````````````
M`````````L42`````````````````````````````KPA````````````````
M`````````````9L2`````````````````````````````AP2````````````
M`````````````````2,2`````````````````````````````@X2````````
M`````````````````````1,2`````````````````````````````042````
M`````````````````````````IH2`````````````````````````````<(2
M`````````````````````````````!`@````````````````````````````
M`7,2`````````````````````````````F,2````````````````````````
M`````KL1`````````````````````````````?D2````````````````````
M`````````"P@`````````````````````````````C@2````````````````
M`````````````$82`````````````````````````````?$2````````````
M`````````````````442`````````````````````````````@<2````````
M`````````````````````&,2`````````````````````````````,`2````
M`````````````````````````'02`````````````````````````````G,2
M`````````````````````````````GTB````````````````````````````
M`8H2`````````````````````````````;T2````````````````````````
M`````*02`````````````````````````````>L2````````````````````
M`````````@`2`````````````````````````````3<2````````````````
M`````````````.82`````````````````````````````=,2````````````
M`````````````````FP2`````````````````````````````B(2````````
M`````````````````````C<2`````````````````````````````JD2````
M`````````````````````````>02`````````````````````````````:,2
M`````````````````````````````(\2````````````````````````````
M`842`````````````````````````````6`2````````````````````````
M`````.$2`````````````````````````````7X2````````````````````
M`````````+,1`````````````````````````````J(2````````````````
M`````````````HP2`````````````````````````````2P2````````````
M`````````````````DT2`````````````````````````````%02````````
M`````````````````````C`2`````````````````````````````E41````
M`````````````````````````YH2```-````````0B`````````!$@```_\2
M```-````````.``````````'B@```K82```-````````(-`````````"4```
M`P$2```-````````+)@`````````!@```R\2```-````````/Y`````````"
MB@``!"42```-````````+*`````````"%@```^40```7````````P(``````
M`````````Q(2```-````````+K@`````````1````T42```-````````-C``
M````````D````Z81```/````````7J0`````````!````\(2```-````````
M6O@````````!-````\T2```-````````*X``````````/````_H0```7````
M````T+``````````````!!,2```-````````-O`````````!"@```[40```6
M````````P````````````````VD2```-````````+P`````````!)@``!`P0
M```6````````P(``````````````!#(1```6````````P'@`````````"```
M`Q\2```-````````7@```````````@```[L2```-````````(R``````````
M`````]42```-````````79@`````````9````_$2```-````````6H@`````
M````;````[<@```6````````P````````````````W\2```-````````-L``
M````````+@```U,2```-````````*\``````````U````W42```-````````
M7#`````````!8@``!#P2```-````````,"@````````&`@!?7V=M;VY?<W1A
M<G1?7P!?251-7V1E<F5G:7-T97)434-L;VYE5&%B;&4`7TE435]R96=I<W1E
M<E1-0VQO;F5486)L90!097)L7W-Y<U]T97)M`%!E<FQ?<WES7VEN:70S`%!E
M<FQ?871F;W)K7VQO8VL`<&5R;%]C;VYS=')U8W0`4&5R;%]G971?<W8`4&5R
M;%]C<F]A:U]N;V-O;G1E>'0`4&5R;%]S=E]S971P=FX`4$Q?9&]?=6YD=6UP
M`%!E<FQ?;F5W6%-?9FQA9W,`4$Q?=&AR7VME>0!P97)L7V9R964`4&5R;%]M
M9U]S970`4&5R;%]A=&9O<FM?=6YL;V-K`%!E<FQ?<W9?<V5T<'8`4&5R;%]G
M=E]F971C:'!V`'!E<FQ?<G5N`%!E<FQ?;F5W6%,`<&5R;%]D97-T<G5C=`!B
M;V]T7T1Y;F%,;V%D97(`<&5R;%]P87)S90!097)L7W-A9F5S>7-M86QL;V,`
M<&5R;%]A;&QO8P!O<&5N-C0`<F5A9`!?7V5R<FYO7VQO8V%T:6]N`&QS965K
M-C0`<'1H<F5A9%]G971S<&5C:69I8P!C;&]S90!E>&ET`'-T<FYC;7``8VQO
M<V5D:7(`7U]S=&%C:U]C:&M?9F%I;`!U;FQI;FL`;6MD:7(`<F5A;&QO8P!M
M96UC:'(`9V5T<&ED`'-T<F1U<`!S=')T;VL`<W1R<W1R`')M9&ER`%]?9G!R
M:6YT9E]C:&L`;65M8W!Y`&QS=&%T-C0`7U]S=')N8W!Y7V-H:P!O<&5N9&ER
M`'-T9&5R<@!G971U:60`<F5A9&QI;FL`<W1R8VAR`')E861D:7(V-`!?7V-X
M85]F:6YA;&EZ90!?7W-P<FEN=&9?8VAK`&UE;6UO=F4`86-C97-S`%]?;&EB
M8U]S=&%R=%]M86EN`%]?96YV:7)O;@!?7W)E9VES=&5R7V%T9F]R:P!L:6)P
M97)L+G-O+C4N,S0`;&EB<'1H<F5A9"YS;RXP`&QI8F,N<V\N-@!P87)?8W5R
M<F5N=%]E>&5C`'!A<E]B87-E;F%M90!?7VQI8F-?8W-U7V9I;FD`6%-?26YT
M97)N86QS7U!!4E]"3T]4`'!A<E]E;G9?8VQE86X`<&%R7V-U<G)E;G1?97AE
M8U]P<F]C`'!A<E]D:7)N86UE`'-H85]F:6YA;`!G971?=7-E<FYA;65?9G)O
M;5]G971P=W5I9`!P87)?8VQE86YU<`!?24]?<W1D:6Y?=7-E9`!?7V1A=&%?
M<W1A<G0`<VAA7W5P9&%T90!X<U]I;FET`%]?;&EB8U]C<W5?:6YI=`!?7V)S
M<U]S=&%R=`!S:&%?:6YI=`!?96YD`'!A<E]M:W1M<&1I<@!?961A=&$`<&%R
M7W-E='5P7VQI8G!A=&@`<&%R7V9I;F1P<F]G`&UY7W!A<E]P;`!P87)?:6YI
M=%]E;G8`1TQ)0D-?,BXR`$=,24)#7S(N-`!'3$E"0U\R+C,S`$=,24)#7S(N
M,RXR`$=,24)#7S(N,RXT`````````@`!``(``@`!``$``P`!``(``0`$``(`
M`0`"``4``@`$``(``0`"``$``0`"``(``0`!``(``@`"``$`!@`!``(``0`"
M``$``0`!``(``@`$``(``0`"``(``0`!``<``@`'``8``@`"``0``0`$``$`
M`@`$``$``@`'``$``@`!``(``@`!``$``0`!``$``0`!``$``0`!``$``0`!
M``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$```+G````$````"`-
M:6D2````!```!$D```````$`!0```O<````0``````UI:10````'```$4P``
M`!`&EI&S````!@``!%T````0"6D9<@````4```1H````$`EI&70````#```$
M=````!`-:6D2`````@``!$D`````````````M!@`````````#````````"#0
M````````P`@`````````#````````,`(````````P!@`````````#```````
M`&&*````````P"``````````#````````%\`````````P#``````````#```
M`````%^@````````P#@`````````#````````%^D````````P$``````````
M#````````&%^````````P$@`````````#````````%\&````````P%``````
M````#````````&&&````````P&``````````#````````&%N````````P&@`
M````````#````````&%T````````P'@`````````#````````&&0````````
ML\`````$````"@``````````````````L\@````'````"@``````````````
M````L]`````+````"@``````````````````L]@````.````"@``````````
M````````L^`````:````"@``````````````````L^@````?````"@``````
M````````````L_`````C````"@``````````````````L_@````E````"@``
M````````````````M``````I````"@``````````````````M`@````]````
M"@``````````````````M!````!$````"@``````````````````L@@````"
M````"P``````````````````LA`````#````"P``````````````````LA@`
M```%````"P``````````````````LB`````&````"P``````````````````
MLB@````(````"P``````````````````LC`````)````"P``````````````
M````LC@````*````"P``````````````````LD`````,````"P``````````
M````````LD@````-````"P``````````````````LE`````/````"P``````
M````````````LE@````0````"P``````````````````LF`````2````"P``
M````````````````LF@````3````"P``````````````````LG`````4````
M"P``````````````````LG@````5````"P``````````````````LH`````6
M````"P``````````````````LH@````7````"P``````````````````LI``
M```8````"P``````````````````LI@````9````"P``````````````````
MLJ`````;````"P``````````````````LJ@````<````"P``````````````
M````LK`````>````"P``````````````````LK@````@````"P``````````
M````````LL`````A````"P``````````````````LL@````B````"P``````
M````````````LM`````D````"P``````````````````LM@````F````"P``
M````````````````LN`````G````"P``````````````````LN@````H````
M"P``````````````````LO`````I````"P``````````````````LO@````J
M````"P``````````````````LP`````K````"P``````````````````LP@`
M```L````"P``````````````````LQ`````M````"P``````````````````
MLQ@````N````"P``````````````````LR`````O````"P``````````````
M````LR@````P````"P``````````````````LS`````Q````"P``````````
M````````LS@````R````"P``````````````````LT`````S````"P``````
M````````````LT@````T````"P``````````````````LU`````U````"P``
M````````````````LU@````V````"P``````````````````LV`````W````
M"P``````````````````LV@````X````"P``````````````````LW`````Y
M````"P``````````````````LW@````Z````"P``````````````````LX``
M```[````"P``````````````````LX@````\````"P``````````````````
MLY`````^````"P``````````````````LY@````_````"P``````````````
M````LZ````!`````"P``````````````````LZ@```!!````"P``````````
M````````L[````!"````"P``````````````````L[@```!#````"P``````
M````ZV_P,``DN00`'Z?[_V#C$/```"3`P```3"[`$```31_C$!````2Y`@`1
MIX0``PWAP.4```5HP.4``"(QXT#Q$``$ZV_PT``$!_0'!^,0\#@`),`0``!,
M#]('\#`0".,0$!``!`?Q!P`'``<`P!```$P.XQ`0```$!_$-$.,0$`P`%,#T
M____Y0````#`$```3`+C$!````0'\0T0XQ`0#``4P/3____5````&,`0``!+
M]N,0$```!`?Q#1#C$!`,`!3`]/___\4````PP!```$OJXQ`0```$!_$-$.,0
M$`P`%,#T____M0```$C`$```2][C$!````0'\0T0XQ`0#``4P/3___^E````
M8,`0``!+TN,0$```!`?Q#1#C$!`,`!3`]/___Y4```!XP!```$O&XQ`0```$
M!_$-$.,0$`P`%,#T____A0```)#`$```2[KC$!````0'\0T0XQ`0#``4P/3_
M__]U````J,`0``!+KN,0$```!`?Q#1#C$!`,`!3`]/___V4```#`P!```$NB
MXQ`0```$!_$-$.,0$`P`%,#T____50```-C`$```2Y;C$!````0'\0T0XQ`0
M#``4P/3___]%````\,`0``!+BN,0$```!`?Q#1#C$!`,`!3`]/___S4```$(
MP!```$M^XQ`0```$!_$-$.,0$`P`%,#T____)0```2#`$```2W+C$!````0'
M\0T0XQ`0#``4P/3___\5```!.,`0``!+9N,0$```!`?Q#1#C$!`,`!3`]/__
M_P4```%0P!```$M:XQ`0```$!_$-$.,0$`P`%,#T___^]0```6C`$```2T[C
M$!````0'\0T0XQ`0#``4P/3___[E```!@,`0``!+0N,0$```!`?Q#1#C$!`,
M`!3`]/___M4```&8P!```$LVXQ`0```$!_$-$.,0$`P`%,#T___^Q0```;#`
M$```2RKC$!````0'\0T0XQ`0#``4P/3___ZU```!R,`0``!+'N,0$```!`?Q
M#1#C$!`,`!3`]/___J4```'@P!```$L2XQ`0```$!_$-$.,0$`P`%,#T___^
ME0```?C`$```2P;C$!````0'\0T0XQ`0#``4P/3___Z%```"$,`0``!*^N,0
M$```!`?Q#1#C$!`,`!3`]/___G4```(HP!```$KNXQ`0```$!_$-$.,0$`P`
M%,#T___^90```D#`$```2N+C$!````0'\0T0XQ`0#``4P/3___Y5```"6,`0
M``!*UN,0$```!`?Q#1#C$!`,`!3`]/___D4```)PP!```$K*XQ`0```$!_$-
M$.,0$`P`%,#T___^-0```HC`$```2K[C$!````0'\0T0XQ`0#``4P/3___XE
M```"H,`0``!*LN,0$```!`?Q#1#C$!`,`!3`]/___A4```*XP!```$JFXQ`0
M```$!_$-$.,0$`P`%,#T___^!0```M#`$```2IKC$!````0'\0T0XQ`0#``4
MP/3___WU```"Z,`0``!*CN,0$```!`?Q#1#C$!`,`!3`]/___>4```,`P!``
M`$J"XQ`0```$!_$-$.,0$`P`%,#T___]U0```QC`$```2G;C$!````0'\0T0
MXQ`0#``4P/3___W%```#,,`0``!*:N,0$```!`?Q#1#C$!`,`!3`]/___;4`
M``-(P!```$I>XQ`0```$!_$-$.,0$`P`%,#T___]I0```V#`$```2E+C$!``
M``0'\0T0XQ`0#``4P/3___V5```#>,`0``!*1N,0$```!`?Q#1#C$!`,`!3`
M]/___84```.0P!```$HZXQ`0```$!_$-$.,0$`P`%,#T___]=0```ZC`$```
M2B[C$!````0'\0T0XQ`0#``4P/3___UE```#P,`0``!*(N,0$```!`?Q#1#C
M$!`,`!3`]/___54```/8P!```$H6XQ`0```$!_$-$.,0$`P`%,#T___]10``
M`_#`$```2@KC$!````0'\0T0XQ`0#``4P/3___TU```$",`0``!)_N,0$```
M!`?Q#1#C$!`,`!3`]/___24```0@P!```$GRXQ`0```$!_$-$.,0$`P`%,#T
M___]%0``!#C`$```2>;C$!````0'\0T0XQ`0#``4P/3___T%```$4,`0``!)
MVN,0$```!`?Q#1#C$!`,`!3`]/___/4```1HP!```$G.XQ`0```$!_$-$.,0
M$`P`%,#T___\Y0``!(#`$```2<+C$!````0'\0T0XQ`0#``4P/3___S5```$
MF,`0``!)MN,0$```!`?Q#1#C$!`,`!3`]/___,4```2PP!```$FJXQ`0```$
M!_$-$.,0$`P`%,#T___\M0``!,C`$```29[C$!````0'\0T0XQ`0#``4P/3_
M__RE```$X,`0``!)DN,0$```!`?Q#1#C$!`,`!3`]/___)4```3XP!```$F&
MXQ`0```$!_$-$.,0$`P`%,#T___\A0``!1``````ZV_P,``DX_#_./]QXS#P
MJ``DXT#PH``D4"#PM$%`\*!!,/"H02#PM+)/`+#KNP`@``VR3P"QT@?PP+`H
MP.7____`Q$@``$E?Q"@``$EPN00`-,#E```><\08``!)<)4`$`"GA`"JQ*@`
M`$E)XR"@```6P.7___\%N00`$N,@H```%I8"%'K`Y?___OM8H/"TE@$D>NPJ
M``0`V+D4`"+K(@`#``W`Y?___QSC,/"H``3C$#````3C$"```"3`$```'^WC
M$"`(`"2GJ@`#Q!@``$]NXQ`@$``DQ"L``$]XP!```!_>XQ`@&``DN00`4E@@
M\+2G+@`!I\0`H4$P,`BG"``$[$+__P#8N10`$..0,```!.L1``,`#>.14```
M)*<*``&G.P`(IT;_\>P2``,`V+D4`!'K$0`#``U!$5``N10`2N5($````*=I
M``#`,```!';$*```3T/`Y?___#(8HA(BIX0`1,0H``!/.4&0\+S`Y?___@;`
M(```'H:Y!``YP.4```$HN0(`(J>$`#G$*```3R7`Y?__^]3`Y?___3&Y%``J
MU0?PP+`HIW0`4.MO\/@`!`?^P.7___SCQ"L``$\.N0(`(J>$`#W`Y?___5G$
MJ```2)3C(*```!;`Y?___E"2`"HGI_3_0\0H``!.]\#E___\9ABBI_3_M\`0
M``!.ZN,@$````J>$``?`Y0``#Z*G]/^^N00`.<`@```>#,#E````V,0K``!.
MU;D"`"*GA/^OI_3_[*<8``2G]/]ZIRD``<#E___]7,#E___]N4%`\`CC,/``
M``2G"?_PN8``\*?[_U#7!_``\`#K[_"@`"1!</"@P&```!U=P%```!TFP"``
M`$ACXR`@```$P.7___W7```'!\`0``!.C,`@``!.B;D@`!('CL08``!(,[D"
M`!$'C@?QP"```$Y\P!```$YYN0D`$NLA``,`"NLQ`#\`#+D(`#+K,P`!``JY
M`@`S!X[$&```2!JY`@`1!X[`(```3F`'\>N?\$@`),"0``!.6>/P_V#_<94`
MD`"G=``^P!```$@/XQ`0```"IX0`",0H``!."\#E___\RL`0``!&"<"P``!&
M"KD)`+'KNP`#``JY!`"AI[O__\08``!.-KDA`!NGI``5IQL``<0;``!.+>L1
M``,`#>,1H```!`WAQ!@``$XCN2$`&Z=$_^_`Y?___XR2`9``ZY_PZ``$!_X'
M!P<'!P?K[_!P`"3C\/]@_W'K[_$0``0'_@<'!P?`]/___X0'!^OO\'``)./P
M_V#_<>OO\1``!`?^!P<'!^MO\#``)./P_V#_<;D"`(*GA`!:Q!@``$>&XW`0
M```"IX0`4KD$`&/C$(```)2Y!`"8E0"``*>$`$^G'@`]IX0`"T&0D`'C$)``
M`)25`)``IW3_]1N8XZ!P```"IX0`'[D4`)FY!`"WN00`2;D$`#BY!``JP.7_
M__N,$B*G=``(01F@`)4]$`"GA``/0;"P"..@L````J=T_^FY!``JZV_PT``$
M!_Y!J:`!N>EP&[D$`"KK$0`#``I0$&``ZV_PT``$!_ZGJ0``N00`*NMO\-``
M!`?^IY@``*?T_[\'!P<'ZV_P,``DX_#^P/]QLD\`H.NJ`"``#;)/`*&Y`@!B
MT@?Q.*`HIX0`!I4`8`"G=``+U0?Q.*`HIW0`E>MO\7``!`?^P.7___U5N0(`
MLJ>$__)!@/"HN00`*\#E___[RKD"`"*GA`!D09`@$Y4N(!.G=``&E0"0`:>$
M_^^5+B`3IX0`8J<(``"Y!``6IRD``+)>`"&G%/_^N00`.:<9``"Y"0`FLEX`
M$Z<4__ZY"0`9&B&G*@`"N10`(L#E___Z:N.0\*``),!0```<,KD$`)*G2?__
MISD``<#E___\Z[D$`#BY!``IP.7___LDIR[__[D$`"FGA``+6!#PP,`;``#P
M`*<>0`"GA``IP.7___Q2N00`*<#E___\G;D$`"O`Y?__^VBY`@`BIW3_H+D$
M`"O`Y?__^?^Y!``FP.7___I:I_3_>94ND`&G=/^>E0"0`J>$_X.G]/^8P.7_
M__]5I_3_V<#E___[U@<'ZZ_P4``DX_#^R/]QLD\`L+D$`*+KNP`@``U!,/"@
MLD\`L=('\3"P*,#E___[[A(BIW0`'Q@26"#PN,`K``#P`*<N0`"GA``'PBT`
M`*``IW0`$KD$`"JG.0`"P.7___QE$!*G&O__B!``'Z?T``2G&```N10`(=4'
M\3"P**=T``;KK_&(``0'_L#E___[C@<'ZW_P.``DX_#_6/YQXQ#PH`%QN00`
MLKD$`*.R3P"`09#PH.N(`"``#;D$`#FR3P"!ITD/_\`@```;@=('$`"`*,#E
M___Z6A(BI\0`,>P2__\`V+D4`'%!-_"@E0`P`*=T`$(2$:>$`".Y!`!'ISD`
M+[D$`"G`Y?__^E"Y`@`BIX0`%L08``!%Y^,@$```%L#E___[H[D$`%>Y!`!)
MN00`.\#E___ZZJ?T`!+$&```1=/C(!```!;`Y?__^X^Y!`!*N00`.\#E___Y
MV.,0\*`!<=4'$`"`**=T``KK?_#@`00'_KD4`'*G]/_!P.7___L5ZV_P,``D
MX_#_2/]QLD\`8.MF`"``#;)/`&&Y!`"RN00`H]('\+!@*)4],`"G=``$0:`P
M`:<(``"Y!``:IXD``+)>`(&G%/_^N0D`BD$P\*RY!``KP.7___WRN0(`(J>$
M`)VG"```IQD``+D$`#*R7@`3IQ3__KD)`!*Y(0"!I\0`>N-P\*P`%,38``!%
M:.MW``,`#>,@L```E+D$`!N5`+``IW0`#:?T`.Y!$!`!XR`0``"4E0`0`*>$
M``:G+@`]IW3_];D)`!NY%``102@0`KD$`)?CD-````C`Y?__^.7C()```"2Y
M`@`BIX0`.^,0L```D.,@T```!.,W(```!$(0,`!!L+`!&$&Y`@`1IW0`$*?T
M`#_C$+```)!"$"`!0;"P`1A!N0(`$:>$`#-"0/"@N00`(Y4]\*!!,#`!IW3_
M[)(](`"G&0``XS&@``"00C$@`:<;``&Y`@`SIW3_]]4'\+!@**=T`)CK;_#H
M``0'_J<9``#C,:```)!",2``IQL``;D"`#.G=/_WI_3_ZKD$`".G]/_7Q-@`
M`$3@XW#0```$XQ!P```"IX0`<+D$`!>GF```&"FGF@`!01`0".,P$````J=T
M__BG*@`#N10`(NLB``,`#<`0``!+*.,0$```$J=T`#?`$```2R#E3!````'`
MY?__^%BY`@`2XQ#PH``DIX3_KKD$`#>Y%`!YZW<``P`-N00`1\#E___XQ>,0
M\*``!.,0T```)%"0\*SC$/"@``2GF@`!N10`F>N9``,`#4$9$`#E2!````"G
M]/\CN00`,KD$`"?`Y?__^17C(/"@`"3C(-```"2Y`@`BIX3_>+D4`'GK=P`#
M``VG]/_7IQD``*?T_R.G*0`0IY@``*?T_Z/`Y?__^<<'!P<'ZV_P,``DX_#_
M6/]QQ+@``$1:XR"P```6P&```!LBP.7___H3XR"P```6P.7___H-P%```#E7
MQ$@``$19P#```!F]P.7___J!XR"P```6P.7___G[N00`5N5(\*```,!````*
M%<`P```9M\#E___XW>MO\-@`!`?^Z^_P<``DQ!@``$0AX_#_8/]QXR`0```6
MP.7___G:P%```#DDQ$@``$0FP#```!F*Z^_Q$``$P/3___I+!P<'!^MO\#``
M)./P_TC]<>,0\+`"<;)/`)#KF0`@``VR3P"1T@<0`)`H0;#PKN.`\*\!<<#E
M___Y'L`0```9@^,0\*``)+D$`&+`4```&76G21`!ISD``;D$`"O`Y?__^@JY
M!``KN00`.*=)$`#`Y?__^"$2(J=$`"JY!`"RIRH``;D4`"+`Y?__]V6Y`@"B
MIX0`#[D4`+NY!``XN00`2\#E___Z*$$;H`"2`!``XQ#PL`)QU0<0`)`HIW0`
M#+D$`"KK;_#H`@0'_J>I``"G]/_PP.7___C_!P<'!\#T____E`<'ZV_P,``D
MX_#^L/YQXQ#Q2`%QN00`HKD$`).R3P"`03#PM.N(`"``#<`@```9';)/`('2
M!Q``@"C`Y?__^^2G.0`ON00`LKD$`"K`Y?__^.&Y`@`BIX0`&,`@```9"KD$
M`#K`Y?___;.Y!``JXQ#Q2`%QU0<0`(`HIW0`S.MO\8`!!`?^IP@``+D$`!JY
M!``IIYD``+)>`)&G%/_^&YK`Y?__]^?`,```&.O`Y?__]S&Y`@!BIX3_TJ>:
M``%!</%(0=#PN)4`8`"GA`!VN0(`NZ>$``ZG"```N00`%KD$`"NR70`2IQ3_
M_J>$`%2Y!``6IP@``*<I``"R7@`AIQ3__KD)`";L$O__`-BY!``VN1@`,94O
M,`"G=``/D@`P`!@AIQK__[D$`#:Y&``QE2\P`*>$__4:*:<N#_^G)/^/P!``
M`!B?XZ#PJ``DXQ#PH``DP%```!D&ITD0`*<Y``&Y!``GP.7___D5N00`/;D$
M`"?`Y?__]TX2(J=T``Q8$/#0P!L``/``PAT``(``IX0`*<`P```8=:<I``#`
MY?__]KFY!`!BN0(`(J>$_UB5`&``IW3_CKD"`+NGA``&E2ZP`*>$``G`8```
M&$ZG*``!I_3_LY4`L`&GA/_=I_3_]:<Y``&Y!``GP.7___C#$B*G=/_1N00`
M-\`@```8.\#E___\YKD$`"?`Y?__]S.G]/\PP.7___?N!P>5`"``N00`$N,P
M(```E`>.ISX`+T$0$`&YXH`AXS`0``"4E0`0``>.ISX`+T$0$`&YXH`AXS`0
M``"4E0`0`*=T_^D'_@<'!P>Y`@`RIX0`A94`,`"GA`"!IP@``*<9``"Y!``C
MLEX`$J<4__[C$!___W&YZ3!!N2$`,:>D`'25+Q``IW0`$>,0'___<:='__F5
M+S``IX0`8<`@```7YL#T___VV[DA`#&GI`!=N>DP0>,0'___<:='``2G]/_K
ME2\0`*=T__>YZ3!!XR`?__]QN2$`,J<D`#VG/___IX0`.>,0'___<:='`".Y
M"0`3["$``@#9PBX``!``IR0`)T%`$`&G61``P"```$AYZ^_P<``DX_#_8/]Q
MP.7___5.P"```$AMZ^_Q$``$!_Z5+Q``IX3_V+D)`!/L(0`"`-G"+@``$`"G
MQ/_=IRD```?^ITD``:?T_\?`(```%WG`]/__]GRY(``QIW3_L*?T_Y,'!^NO
M\%``)./P_S#_<;)/`+#KNP`@``VR3P"QP!```#;20:#PH-('\,BP*-(A\*80
M"KD$`#K`(```%V'`Y?__^A^Y`@`BIX0`,,0H``!!J.,0\*``%.L1``,`#>,0
M(```".,@$`@`!.,@$```)+D"`"*GA/_@XR`0$``$XR`0"``D01`0"+D"`"*G
M=/_VN00`.L`@```7,\#E___Y\;D"`"*G=/_4N00`.L`@```7+,#E___YY;D"
M`"*GA``PQ"@``$%NXQ#PH``4ZQ$``P`-XQ`@```(XR`0"``$XR`0```DN0(`
M(J>$_^#C(!`0``3C(!`(`"1!$!`(N0(`(J=T__:Y!``ZP"```!;^P.7___FW
MN0(`(J=T_]2Y!``ZP"```!;VP.7___FKN0(`(J>$`##$*```033C$/"@`!3K
M$0`#``WC$"````CC(!`(``3C(!```"2Y`@`BIX3_X.,@$!``!.,@$`@`)$$0
M$`BY`@`BIW3_]KD$`#K`(```%LC`Y?__^7VY`@`BIW3_U+D$`#K`(```%L'`
MY?__^7&Y`@`BIX0`,,0H``!`^N,0\*``%.L1``,`#>,0(```".,@$`@`!.,@
M$```)+D"`"*GA/_@XR`0$``$XR`0"``D01`0"+D"`"*G=/_VN00`.L`@```6
MD\#E___Y0[D"`"*G=/_4N00`.L`@```6B\#E___Y-[D"`"*GA``PQ"@``$#`
MXQ#PH``4ZQ$``P`-XQ`@```(XR`0"``$XR`0```DN0(`(J>$_^#C(!`0``3C
M(!`(`"1!$!`(N0(`(J=T__:Y!``ZP"```!9=P.7___D)N0(`(J=T_]2Y!``Z
MP"```!99P.7___C]N0(`(J>$`##$*```0(;C$/"@`!3K$0`#``WC$"````CC
M(!`(``3C(!```"2Y`@`BIX3_X.,@$!``!.,@$`@`)$$0$`BY`@`BIW3_]KD$
M`#K`(```%BO`Y?__^,^Y`@`BIW3_U+D$`#K`(```%??`Y?__^,.Y`@`BIX0`
M,,0H``!`3.,0\*``%.L1``,`#>,0(```".,@$`@`!.,@$```)+D"`"*GA/_@
MXR`0$``$XR`0"``D01`0"+D"`"*G=/_VN00`.L`@```5R<#E___XE;D"`"*G
M=/_4N00`.L`@```5Z\#E___XB;D"`"*GA``PQ"@``$`2XQ#PH``4ZQ$``P`-
MXQ`@```(XR`0"``$XR`0```DN0(`(J>$_^#C(!`0``3C(!`(`"1!$!`(N0(`
M(J=T__:Y!``ZP"```!6]P.7___A;N0(`(J=T_]2Y!``ZP"```!6VP.7___A/
MN0(`(J>$`##$*```/]CC$/"@`!3K$0`#``WC$"````CC(!`(``3C(!```"2Y
M`@`BIX3_X.,@$!``!.,@$`@`)$$0$`BY`@`BIW3_]KD$`#K`(```%8C`Y?__
M^"&Y`@`BIW3_U+D$`#K`(```%8'`Y?__^!6Y`@`BIX0`,,0H```_GN,0\*``
M%.L1``,`#>,0(```".,@$`@`!.,@$```)+D"`"*GA/_@XR`0$``$XR`0"``D
M01`0"+D"`"*G=/_VN00`.L`@```54\#E___WY[D"`"*G=/_4N00`.L`@```5
M%,#E___WV[D"`"*GA``PQ"@``#]DXQ#PH``4ZQ$``P`-XQ`@```(XR`0"``$
MXR`0```DN0(`(J>$_^#C(!`0``3C(!`(`"1!$!`(N0(`(J=T__:Y!``ZP"``
M`!3FP.7___>MN0(`(J=T_]2Y!``ZP"```!42P.7___>AN0(`,J>$``C`(```
M%/[`Y?__^7NY!``ZP"```!4)P.7___>/N0(`,J>$``C`(```%0C`Y?__^6FY
M!``ZP"```!4&P.7___=]N0(`,J>$`!K`(```%*?`Y?__^5?`,```%0W`(```
M%+[`Y?__^4[5!_#(L"BG=``FZZ_Q(``$!_ZY!``ZP"```!3JP.7___=9N0(`
M,J>$``K`(```%+'`Y?__^3.G]/_<P!```!3AU0D0`/"WIW3_U$$P\,&G]/_N
MP.7___0T!P<'!P<'Z[_P6``DX_#_4/]QLD\`L.N[`"``#;)/`+'$+0``1..G
M+O__T@?PJ+`HIX0`#;D4`"+5!_"HL"BG=``IZ[_Q"``$!_Y!,/"DP"```!1S
MP.7___<1N0(`(J>$`!6_$2``IX0`$<`7````,+F$`!&Y`P`A["(_OP%5Q"\`
M`$2TI_3_V*<H``"G]/_YP.7___/IZ^_P<``DX_#_8/]QP.7___&PP.7___&-
MN0(`(J>$``7C("````3K[_$0``0'_@<'ZV_P,``DX_#_0/]QLD\`H+D$`&+K
MJ@`@``U!,/"TLD\`H<`@```49=('\+B@*,#E___VP;D"`+*GA``8E0"P`*>$
M`!2Y!``VP.7___':N0(`(J>$`!O5!_"XH"BG=`!4ZV_P\``$!_[5!_"XH"BG
M=`!+N00`-L`@```4.^MO\/``!,#T___X>Z<(``"Y!``6N00`.[)>`"&G%/_^
MIQD``+D)`":R7@`3IQ3__KD)`!M!(A`"P.7___&TP!```!.XX[#PJ``DXQ#P
MH``DN00`LL!0```4'J=)__^G.0`!P.7___0OU0?PN*`HIW0`#;D$`#O`(```
M$_WK;_#P``3`]/__^#W`Y?__\TP'!P<'!P?K;_`P`"3`$```1`7C\/X`]W&R
M3P#0XS#Q^`AQZ]T`(``-LD\`T;D$`')!@/#$P"```!-JT@<P`-`HT@_PR!`(
MT@?PV!`8TB_P^!`@T@_PX!!0T@?P\!!@N00`.,#E___V(KD"`+*GA``&E0"P
M`*=T`E[`Y?__\-W`Y?__\+JY`@`BIX0!_N.P(````J>$`?FG"```N00`&Z<I
M``"R7@`AIQ3__KD)`"OK(@`!``VG*P`!P.7___$ME0"P`.-@L```E+D$`)*G
MA``=N00`J;D4`&:Y!``JP%```!./ITG__Z<Y``'`Y?__\Z1!L+`!0:"@`N-@
ML```E)4`L`"G=/_I0:#Q`,`@```33J?T``FGJP`(XR"O^/\"IX0`F[D$`#C`
MY?__]<"Y`@"RIX3_\I4`L`"GA/_NP.7___;9$B*GA/_HN00`*\#E___QX[D"
M`&*GA`!_IP@``+D$`!:GN0``LEX`L:<4__ZY!``IIQD``+D)`+:R7@`2IQ3_
M_KD)`!D:L:>Z!`2Y%`"[N00`*\#E___PO\`0```3..,0\*@`)..0\+``),`0
M```2N^,0\*``)+D$`)+`4```$R*G2?__ISD``<#E___S-+D$`"FG.0'`P.7_
M__(=IR[__Z=T``O`Y?__\>98$"``IQX`$:=T`8)!,/$HN00`*<#E___R>1BB
M$B*GA`!6Q!@``#T$N00`:>-0<```!,!````3%^,@$```!*<Y``&GN0``P.7_
M__)0XQ#Q^`AQU0<0`-`HIW0"H[D$`"OK;_(P"`0'_J>H``"Y%``:ZQ$``P`-
MX['PR``"IX0`(Y4`L`"GA``?IZH``;D$`"O`Y?__]CD2(J>$_^JY!``KP.7_
M__%#N0(`8J=T_V*Y%``:ZQ$``P`-X['PR``"IW3_X:=I``"G]/]46!#Q0,`;
M``#P`*<>0`"G=/^E6&#Q1,#E___OLQEBIW3_G5@0\4#`&P```?^G'@'`IW3_
ME+D$`"O`Y?__\!*Y!``XN00`LL`@```2TL#E___TTKD"`#*GA`$EXR!P```$
MP.7___C(N0(`8J>$`1NG"```IQD``+D$`":R7@`2IQ3__KD)`!:G'@`#I\0`
M'KD4`"'`,```$J_C(F_\_W&R70`RIQ3__J=T`!"G'@`$IX0!NJ<:__NY%``1
M01%@`)4O$`"GA`&PQ!T``$)-IQ[__Z>$`8L2$:>$`/#`,```$BC`(```$>?`
MY?__]FFY!`!IP.7___%&P!```!+?XQ#PL``DXR#PJ``DP!```!&RP%```!)_
MXQ#PH``DITG__Z<Y``&Y!``KP.7___(KI_0`,L#E___PYE@0(`"G'@`1IW0`
M-*>J``&Y!`!IP.7___$9P!```!*RXQ#PN``DXR#PJ``DP!```!&%XQ#PH``D
MP%```!)6N10`&J=)___C$/"P`"2G.0`!N00`*\#E___Q^:<Y`<"Y!``KP.7_
M__#BIR[__Z>$_\>Y!``IP.7___&YN00`.\`@```13\#E___U_[D$`"O`Y?__
M_3ZG]/[<IZ@``+D4`!KK$0`#``WC(?#@``*GA``BIZH``;D$`#C`Y?__]`&Y
M`@`2IX3_[94`$`"GA/_IP.7___`LN0(`LJ=T_>FY%``:ZQ$``P`-XR'PX``"
MIW3_XJ<I``W`L```$8G`Y?__[Q:G:`!3N00`DJ?T_>ZY%``1XQ#PH``DN00`
M:<08```[B.-0<```!,!````1?^,@$```!*<Y``&GN0``P.7___#6I_3^AL#E
M___\X^,0\?@(<=4'$`#0**=T`22Y!``KZV_R,`@$P/3__^_AXV!P```$I_3^
MY,`0``!!6^5,$````+D$`":G.0``P.7___$_N00`@AAB$B*GA/\'ITD``J<Y
M_^[`Y?__[N)!H/'XITD`!KD$`#JY!``HP.7___#WE0#Q^*=T``:50_'YIX0`
MM;D$`"BG20``ISD``+D4`(;`Y?__[L3`Y0``#E^Y!`!BI_0`"[D4`$*Y!``Z
MN00`)L#E```.BJ5/@`"Y!``ZN00`*,#E___PRQ(BIR3_[;D$`"BGJ0`4P.7_
M_^YA02#QN[D$`#:Y!`!R08#QS\#E```/".-@<```D+D$`"C`4```$.*G>P`!
MITG__Z<Y``&GBP`"P.7___#SIZ?_[<`0```1BN,0\+``))(`\?=!$/'/N00`
M:>,0\*@`),`0```05^,0\*``),!0```1&:=)__^G.0`!N00`*\#E___PT*?T
M_N*Y!``XP"```!!BP.7___,`N0(`(J>$_UCC$"```)02$:>$_U*G'@`PP!``
M`$"IIX3_3N5,$````:?T_E[C('`(``*GA/Y/IP@``*<9``"Y!``RLEX`$Z<4
M__ZY"0`2PAX````#I\3^/N,Q+_S_<<`0```0T;)=`!.G%/_^N>*`8J?T_C"5
M0?'ZIW3_2Y5#\?NG=/]'E4CQ_*=T_T.51?']IW3_/Z=)``*G.?_&N00`*+D$
M`&G`Y?__[@&Y!``HITD`*;D$`#K`Y?__\!C`$```$0'CH/"H`"3C$/"P`"3`
M$```#]3C$/"@`"2G]/]]P.7__^^$!P<'!P<'ZW_P.``DX_#_4/]QQ+@``#H6
MLD\`D.,@L```%NN9`"``#;)/`)'2!_"HD"A!@/"DP.7__^_&N00`HN,@L```
M%L#E___OOKD$`!*Y!``XP"````^RT@`0L:"PP.7___);N0(`(J>$``:5,2``
MIX0`T<#E___X%.,@L```%L#E___OH*=9``.G20`!P#```!!AP.7__^W6N0(`
MHJ>$`![C(+```!;`Y?__[XSC$*`0``3`0```$$_C,!````3`Y?__[=#C$*`0
M``3C$!````210!`-IW0`N.,@L```%L#E___O<*=9``.G20`!P#```!`UP.7_
M_^VFN0(`HJ>$`""Y!``XP"````\]P.7___($6!"P`+D"`'*Y%@`AIX0`@,#E
M___O3^,0H!``!+D$`$?C,!````3`Y?__[93C(+```!;`Y?__[SZY!`"BXR"P
M```6P.7__^\VITD``<`P```/_L#E___LKL!````0`[D$`#*Y!``JP.7__^UT
MXR"P```6P.7__^\>D@`@L;D$`#C`(```#O+`Y?__\;[$*P``/[NY!`"RN0(`
M(J>$`!ZG.0'`N00`*\#E___N9*<N`!&GA``*[!(``0#8PA\````!IR0`2]4'
M\*B0**=T`%;K?_#H``0'_L0H```_DL#E___[0\0K```_D+D$`+*Y`@`BIW3_
MU\`@```/N,#E___NZI4`(`&GA/\RI_3_+<#E___NT<08```_=.,@H!``!.,P
M$```!.,@(```!,#E___RV*?T_W[C(+```!;`Y?__[KKC$*`0``3C,!````3`
MY?__[D&G]/\[Q!@``#]2N00`4KD$`$O`(```#Y'C,!````3`Y?__[J_`Y?__
M[CP'!P<'!P?KG_!(`"3C\/]0_W&R3P"0N00`HNN9`"``#;)/`)'2!_"HD"C`
MY?__]E[C$"```)2Y!`"RE0`@`*>$``^G'@`O02`@`;GB@++C$"```)25`"``
MIW3_]<0=```^S:<>__^GA``6$A&GA``*N0(`JJ>$``:5`*``IW0`*=4'\*B0
M**=T`$;KG_#X``0'_D$P\*3`(```#E?`Y?__\/6Y`@`BIX0`+N,0(```E!(1
MIX0`**<>`##`$```/IZGA``DY4P0```!I_3_T[D$`"NG20`$P#````Z*P.7_
M_^R;$B*G=/_.U0?PJ)`HIW0`$KD$`"KKG_#X``3`]/__\37`$```/GKE3!``
M``"G]/^YP.7__^VP!P<'!P<'ZV_P,``DIUD`"./P_-#_<;)/`*!!$/"HZZH`
M(``-0;`@.+)/`*&Y!`!!T@?S**`HXS"P```$ZP,`(``,XP!````DP#H`````
MXS!`"``D0;"P"*=+`!"G5__MITD`0.,P$&@`!.,P$$``@N,P$!``@N,P$```
M@NQ3(+\A5>Q3(#X!5N-0$(``)*<;``BG1__IX[`@&``$XY#PL``$PII:@GF9
MN0@`F^-`(```!.,`(`@`!.,`\*``).-0(!``!.PT(+\E5>MP``(`#.PT(#H%
M5NQP`"$>5NR'(+\`5;GG@!6Y@``4N8(`%;GHD-&YY["5N8``D+F"`)OC$/"H
M``3"&EJ">9GC$"`@``BY"``3ZS0``@`,N0@`&>PT`"$>5NR1(+\`5;GG,&?L
M$3N_)56Y@`!I[!D`.@56N8(`:+D(`!WL<2"_`%7LT3N_)57LUP`Z!5;C$/"X
M``3C`/#```3"&EJ">9G""EJ">9FY"``5N0@`"+D(`!;KB0`"``SL8R"_`%7L
MB0`A'E:Y"``=N8(`..S1.[\E5>R1(+\`5;GD<!.Y!``]X]#PR``$[#D`.@56
MPMI:@GF9N8(`%KD(`!"YZ&`-N0@`$^QH(+\`5>S1.[\E5>LW``(`#.PW`"$>
M5KF"`(/L<2"_`%6YY)`8N00`C>/0\-``!.R'`#H%5L+:6H)YF;F"`!:Y"``0
MN>A@#;D(`!CL8R"_`%7LT3N_)57KB0`"``SLB0`A'E:Y@@`X[)$@OP!5N>1P
M$[D$`#WCT/#8``3L.0`Z!5;"VEJ">9FY@@`6N0@`$+GH8`VY"``3[&@@OP!5
M[-$[OR55ZS<``@`,[#<`(1Y6N8(`@^QQ(+\`5;GDD!BY!`"-X]#PX``$[(<`
M.@56PMI:@GF9N8(`%KD(`!"YZ&`-N0@`&.QC(+\`5>S1.[\E5>N)``(`#.R)
M`"$>5KF"`#CLD2"_`%6YY'`3N00`/>/0\.@`!.PY`#H%5L+:6H)YF;F"`!:Y
M"``0N>A@#;D(`!/L:""_`%7LT3N_)57K-P`"``SL-P`A'E:Y@@"#['$@OP!5
MN>20&+D$`(WCT/#P``3LAP`Z!5;"VEJ">9FY@@`6N0@`$+GH8`VY"``8[&,@
MOP!5[-$[OR55ZXD``@`,[(D`(1Y6N8(`..R1(+\`5;GD<!.Y!``]X]#P^``$
M[#D`.@56PMI:@GF9N8(`%KD(`!"YZ&`-N0@`$^QH(+\`5>S1.[\E5>LW``(`
M#.PW`"$>5KF"`(/L<2"_`%6YY)`8N00`C>/0\0``!.R'`#H%5L+:6H)YF;F"
M`!:Y"``0N>A@#;D(`!CL8R"_`%7LT3N_)57KB0`"``SLB0`A'E:Y@@`X[)$@
MOP!5N>1P$[D$`#WCT/$(``3L.0`Z!5;"VEJ">9FY@@`6N0@`$+GH8`VY"``3
M[&@@OP!5[-$[OR55ZS<``@`,[#<`(1Y6N8(`@^QQ(+\`5;GDD!BY!`"-X]#Q
M$``$[(<`.@56PMI:@GF9N8(`%KD(`!"YZ&`-N0@`&.QC(+\`5>S1.[\E5>N)
M``(`#.R)`"$>5KF"`#CLD2"_`%6YY'`3N00`/>/0\1@`!.PY`#H%5L+:6H)Y
MF;F"`!:Y"``0N>A@#;D(`!/L:""_`%7LT3N_)57K-P`"``SL-P`A'E:Y@@"#
M['$@OP!5N>20&+D$`(WCT/$@``3LAP`Z!5;"VEJ">9FY@@`6N0@`$+GH8`VY
M"``8[&,@OP!5[-$[OR55ZXD``@`,[(D`(1Y6N8(`..R1(+\`5;GD<!.Y!``]
MX]#Q*``$[#D`.@56PMI:@GF9N8(`%KD(`!"YZ&`-N0@`$^QH(+\`5>S1.[\E
M5>LW``(`#.PW`"$>5KF"`(/L<2"_`%6YY)`8N00`C>/0\3``!.R'`#H%5L+:
M6H)YF;F"`!:Y"``0N>A@#;D(`!CL8R"_`%7LT3N_)57KB0`"``SLB0`A'E:Y
M@@`X[)$@OP!5N>1P$[D$`#WCT/$X``3L.0`Z!5;"VEJ">9FY@@`6N0@`$+GH
M8`VY"``3[-@@OP!5ZS<``@`,[#<`(1Y6N><P:..`\4``!,**6H)YF>QQ.[\E
M5;F``&GL<2`Z!5:Y@@!MP!H`````N0@`8+GHT`CL@R"_`%6Y"`!GZWD``@`,
M['D`(1Y6[)8[OR55N>=PT^R6(#H%5KF``-'C,/%(``2Y@@#8PCINV>NAN0@`
M..N!``(`#.R!`"$>5KGG@!>Y@@`6N0@`T+D:`#&Y"`#9[)T[OR55[)T@.@56
ML\$`";/-`!"Y"``Q[!,[OR55[!,@.@56XY#Q4``$L\$``<*:;MGKH;D:`)?L
M=B*_/E7L=@(A'E:YYW`8N8(`'>QM(K\^5;D:`)'L;0(A'E:SS0`0N0@`D>,0
M\5@`!,(:;MGKH;D:`!CLV3N_)57LV2`Z!5:YYV"'N8(`@[D:`!BY"``=[-$[
MOR55[-$@.@56XX#Q8``$L\$`#<**;MGKH;D:`(?L<R*_/E7L<P(A'E:YYW#6
MN8(`V;/-``"Y&@"-XS#Q:``$PCINV>NAN1H`-NQI(K\^5>QI`B$>5KGG8->Y
M@@#1N0@`@+D:`#WLF#N_)57LF"`Z!5:SP0`)L\T``+D(`##LTSN_)57LTR`Z
M!5;CD/%P``2SP0`-PIINV>NAN1H`E^QQ(K\^5>QQ`B$>5KGG<-:Y@@#8L\T`
M`+D:`)WC$/%X``3"&F[9ZZ&Y&@`6[&@BOSY5[&@"(1Y6N>=@U[F"`-.Y"`"0
MN1H`'>R).[\E5>R)(#H%5K/!``BSS0``N0@`$.S1.[\E5>S1(#H%5N.`\8``
M!+/!``W"BF[9ZZ&Y&@"'[',BOSY5[',"(1Y6N>=PUKF"`-FSS0``N1H`C>,P
M\8@`!,(Z;MGKH;D:`#;L:2*_/E7L:0(A'E:YYV#7N8(`T;D(`("Y&@`][)@[
MOR55[)@@.@56L\$`";/-``"Y"``P[-,[OR55[-,@.@56XY#QD``$L\$`#<*:
M;MGKH;D:`)?L<2*_/E7L<0(A'E:YYW#6N8(`V+/-``"Y&@"=XQ#QF``$PAIN
MV>NAN1H`%NQH(K\^5>QH`B$>5KGG8->Y@@#3N0@`D+D:`!WLB3N_)57LB2`Z
M!5:SP0`(L\T``+D(`!#LT3N_)57LT2`Z!5;C@/&@``2SP0`-PHINV>NAN1H`
MA^QS(K\^5>QS`B$>5KGG<-:Y@@#9L\T``+D:`(WC,/&H``3".F[9ZZ&Y&@`V
M[&DBOSY5[&D"(1Y6N>=@U[F"`-&Y"`"`N1H`/>R8.[\E5>R8(#H%5K/!``FS
MS0``N0@`,.S3.[\E5>S3(#H%5N.0\;``!+/!``W"FF[9ZZ&Y&@"7['$BOSY5
M['$"(1Y6N>=PUKF"`-BSS0``N1H`G>,0\;@`!,(:;MGKH;D:`!;L:"*_/E7L
M:`(A'E:YYV#7N8(`T[D(`)"Y&@`=[(D[OR55[(D@.@56L\$`"+/-``"Y"``0
M[-$[OR55[-$@.@56XX#QP``$L\$`#<**;MGKH;D:`(?L<R*_/E7L<P(A'E:Y
MYW#6N8(`V;/-``"Y&@"-XS#QR``$PCINV>NAN1H`-NQI(K\^5>QI`B$>5KGG
M8->Y@@#1N0@`@+D:`#WLF#N_)57LF"`Z!5:SP0`)L\T``+D(`##LTSN_)57L
MTR`Z!5;CD/'0``2SP0`-PIINV>NAL\T``+D:`)?L<2*_/E7L<0(A'E:YYW#6
MN8(`V.,0\=@`!+D:`)W"&F[9ZZ&Y"`"0N1H`%NS8(K\^5>QI(+\`5>S8`B$>
M5NP).[\E5;GGT(?L!@`Z!5:Y@@"#N1H`&+D(`!#L@R*_/E7L@P(A'E;C,/'@
M``2YYX`-PCINV>NAN8(`D+D:`#?L<2"_`%7L$3N_)57L%P`Z!5:Y&@`YXY#Q
MZ``$N0@`,<*:CQN\W.L6``(`#+D:`)WL%@`A'E;LT2"_`%6YY-`(L\$`*>QC
M.[\E5>R3(+\`5;GF$#BY@``WN8$`,.,`\?``!,(*CQN\W.QI`#H%5K/!``"S
MS0`"N0@`,+/-``"Y"``VN1H`".MG``(`#.QG`"$>5KGDT':Y@0`6N8``&;F!
M`!?C</'X``2Y"``0PGJ/&[S<N>C0!^R#(+\`5;/!`"#L,SN_)57L.``Z!5:Y
M"``QZQD``@`,[!D`(1Y6[-$@OP!5N>30!KGF$):Y@`"8N8$`D.,`\@``!,(*
MCQN\W+/!``#L<R"_`%6SS0`"N0@`D.PS.[\E5;/-``"Y&@`&ZV@``@`,[&@`
M(1Y6N>30ANPW`#H%5KF!`!:Y@``7N8$`&..`\@@`!+D(`!#"BH\;O-RYZ-`(
MN0@`D[/!`"#L.2"_`%7KAP`"``SLF3N_)57LAP`A'E;LDP`Z!5;L>""_`%6Y
M"``9N>1P!NS1(+\`5>R1.[\E5;GF@!;LG0`Z!5:Y@``3N8$`$.,`\A``!,(*
MCQN\W+/!``"SS0`"N0@`$+D(`!GKDP`"``SLDP`A'E:YYI`XN>1PB;F``#VS
MS0``N8$`.+D:``;L82"_`%6Y"``P[!$[OR55[!8`.@56N0@`,>R#(+\`5>L=
M``(`#.P=`"$>5KGF$`FSP0``[#,[OR55XP#R&``$[#@`.@56P@J/&[S<L\$`
M([D$`#"Y"``WL\$`0[/-``3LT2"_`%6SS0`PN>30>;F``#:Y@0`WN0@`,+/-
M``+C</(@``2Y"``PPGJ/&[S<N1H`>>N6``(`#+/!``?LE@`A'E:SS0``N>30
M:;F!`!FY@``8N8$`%N-@\B@`!+D(`!#":H\;O-RYZ-`&[',@OP!5L\$`(.PS
M.[\E5>PW`#H%5KD(`#'K&``"``SL&``A'E;LT2"_`%6YY-`)[&,@OP!5[(,[
MOR55N>80.;F``#>Y@0`PXP#R,``$P@J/&[S<L\$``+/-``*Y"``PL\T``+D:
M``GKEP`"``SLEP`A'E:YY-!Y[(8`.@56N8$`&;F``!:Y@0`7XW#R.``$N0@`
M$,)ZCQN\W+GHT`>Y"``XL\$`(.R#(+\`5>PS.[\E5>PX`#H%5KD(`#'K%@`"
M``SL%@`A'E;LT2"_`%6YY-`)[',@OP!5[&,[OR55N>80.;F``#BY@0`PXP#R
M0``$P@J/&[S<L\$``+/-``*Y"``PL\T``+D:``GKF``"``SLF``A'E:YY-")
M[&<`.@56N8$`&;F``!>Y@0`8XX#R2``$N0@`$,**CQN\W+GHT`BY"``VL\$`
M(.QC(+\`5>PS.[\E5>PV`#H%5KD(`#'K%P`"``SL%P`A'E;LT2"_`%6YY-`)
M[(,@OP!5[',[OR55N>80.;F``#:Y@0`PXP#R4``$P@J/&[S<L\$``+/-``*Y
M"``PL\T``+D:``GKE@`"``SLE@`A'E:YY-!I['@`.@56N8$`&;F``!BY@0`6
MXV#R6``$N0@`$,)JCQN\W+GHT`:Y"``WL\$`(.QS(+\`5>PS.[\E5>PW`#H%
M5KD(`#'K&``"``SL&``A'E;LT2"_`%6YY-`)[&,@OP!5[(,[OR55N>80.;F`
M`#>Y@0`PXP#R8``$P@J/&[S<L\$``+/-``*Y"``PL\T``+D:``GKEP`"``SL
MEP`A'E:YY-!Y[(8`.@56N8$`&;F``!:Y@0`7XW#R:``$N0@`$,)ZCQN\W+GH
MT`>Y"``XL\$`(.R#(+\`5>PS.[\E5>PX`#H%5KD(`#'K%@`"``SL%@`A'E;L
M82"_`%6YY&`)[',@OP!5[-,[OR55N>80.;F``#BY@0`PXP#R<``$P@J/&[S<
ML\$``+/-``*Y"``PL\T``+D:``GKF``"``SLF``A'E:YY&")[-<`.@56N8$`
M&;F``!>Y@0`8XX#R>``$PHJ/&[S<N0@`$+D(`#VYZ&`([-,@OP!5[#,[OR55
M[#T`.@56N0@`,>R#.[\E5>R#(#H%5NL7``(`#+/!``CL%P`A'E;L@2"_`%6Y
MY(!IN>80>;F``'VY@0!VXV#R@``$N0@`<,)JCQN\W+/-``"Y&@!IN>@`E[/!
M`";K?0`"``SL:3N_)57L?0`A'E;L:2`Z!5:YY(`'P#H`````N00`UKF!`!?C
M8/*(``2Y@``3PFK*8L'6N8$`$+GH@`;C8/*0``2SP0``PFK*8L'6L\T``KD:
M`&>Y"``0ZX,``@`,N0@`'>R#`"$>5K/-``"YYX#7[#$[OR55N8(`V>PQ(#H%
M5KD:``VSP0`FN0@`,.QC.[\E5>QC(#H%5NQY(K\^5;/!`$;L>0(A'E;CT/*8
M``2YYW!HPMK*8L'6N8(`8;D:`-BSS0`$L\$`#;/-`)*Y&@"6[&$BOSY5[&$"
M(1Y6N>=@U[F"`-.Y"`"0L\T``.P9.[\E5;D:``WL&2`Z!5:Y"``0[-$[OR55
M[-$@.@56XX#RH``$L\$`#<**RF+!UKD:`(?L<R*_/E7L<P(A'E:YYW#6N8(`
MV;/-``"Y&@"-XS#RJ``$PCK*8L'6N1H`-NQI(K\^5>QI`B$>5KGG8->Y@@#1
MN0@`@+D:`#WLF#N_)57LF"`Z!5:SP0`)L\T``+D(`##LTSN_)57LTR`Z!5;C
MD/*P``2SP0`-PIK*8L'6N1H`E^QQ(K\^5>QQ`B$>5KGG<-:Y@@#8L\T``+D:
M`)WC$/*X``2Y"`"0PAK*8L'6[-D[OR55N1H`%NS9(#H%5NQH(K\^5>QH`B$>
M5KGG8(>Y@@"#L\$`#;D:`!BSS0``X]#RP``$N0@`$,+:RF+!UNR!.[\E5;D:
M`-?L@2`Z!5;L<R*_/E6SP0`([',"(1Y6L\T``+GG<(;C,/+(``2Y@@")PCK*
M8L'6N1H`-KD$`&WLV2*_/E6Y&@!HN0@`8.S9`B$>5KGGT)>Y@@"1[(8[OR55
MN1H`.;D$`)CLEB`Z!5:Y"``YXX#RT``$[),[OR55[),@.@56PHK*8L'6L\$`
M";D:`(>SS0``['$BOSY5['$"(1Y6XQ#RV``$N>=PG<(:RF+!UKF"`):Y&@`=
M[-8BOSY5[-8"(1Y6N>?09[F"`&.Y&@")N1H`%KD(`(#LF#N_)57LF"`Z!5:S
MP0`)L\T``+D(`!#L83N_)57L82`Z!5;CD/+@``2SP0`&PIK*8L'6N1H`E^QS
M(K\^5>QS`B$>5KGG<&VY@@!HL\T``+D:`);C,/+H``3L:"*_/E7".LIBP=;L
M:`(A'E:Y&@`]N>=@U[F"`-&Y"`"0N1H`/>R).[\E5>R)(#H%5K/!``BSS0``
MN0@`,.S3.[\E5>S3(#H%5N.`\O``!+/!``W"BLIBP=:Y&@"'['$BOSY5['$"
M(1Y6N>=PUKF"`-FSS0``N1H`C>,0\O@`!,(:RF+!UKD:`!;L:2*_/E7L:0(A
M'E:YYV#7N8(`T[D(`("Y&@`=[)@[OR55[)@@.@56L\$`";/-``"Y"``0[-$[
MOR55[-$@.@56XY#S```$L\$`#<*:RF+!UKD:`)?L<R*_/E7L<P(A'E:YYW#6
MN8(`V+/-``"Y&@"=N0@`D.S9.[\E5>S9(#H%5N,P\P@`!+/!``W".LIBP=:S
MS0``N1H`-N/0\Q``!.QH(K\^5<+:RF+!UNQH`B$>5KD:`->YYV"'N8(`@;D:
M`#BY"``P[',[OR55[',@.@56[($BOSY5L\$`!^R!`B$>5K/-``"YYX!VN8(`
M>;D:`-?C$/,8``3L>2*_/E7"&LIBP=;L>0(A'E:Y&@`6N>@`;;GG<`BY!`#7
MX]`@(``(P-H`````X]`@(``D[)8@OP!5N><PT.P&.[\E5;D:`!WL"0`Z!5:Y
M"``0[-,BOSY5[-,"(1Y6XS#S(``$N>?0!\(ZRF+!UKGHL'VY"``TN>=@L.Q!
M(+\`5;D:`#CL@3N_)56Y!``3[(0`.@56N1H`&[D(`!C`&@````#C$"```"3`
M>@````#C<"`8`"3C,/"@``3K&0`"``RY"``T[!D`(1Y6P#H`````XS`@"``D
MN0@`%<`:`````.,0(!``)-4'\RB@**=T``;K;_-@``0'_L#E___B"`<'!P<'
M!^OO\'``)*<I`(#C\/]@_W'`Y?__X#K`,6=%(P'C,"```"3E2"`H``#`/^_-
MJXGC,"`(`"3E2"`P``#`/YBZW/[C,"`0`"3E3"!X``#`,1`R5';C,"`8`"3`
M/\/2X?#C,"`@`"3K[_$0``0'_@<'!P?K;_`P`"3K%``#``VY!`"2XR`@*``$
MN0@`$NQ1(+\`5;D$`(3C\/]@_W'C0)`P``2Y!`"SN3$`(:?$``2G2P`!XU"0
M*``DZQ@`'0`,N0@`%.,0D#``)$%PD#CC$)!X`!*G=``]IXX`/Z?$`&+L:/_`
M`-B(8``&[!8``0#8[!$?N095[*'_P`#90=&P`.NJ``8`#*>K``'2/W``L`"Y
M!``I0;"P0,#E___SSJ>G__:GBO_`B6``!AN&N10`B+D$`#VY!``GN00`2,#E
M___B=E"`D'CK;_#0``0'_J>H`$`;H1FHN00`.[GR,*BY!``GN10`:KD$`$:Y
M&``AP.7__^)=&!I:$)!X4!"0>*<>`$"G=/_BN?F@J+D(`+:Y%`"*N00`*<#E
M___SCZ?T_YZY!`#;I_3_Q@<'!P?KC_!``"2Y!`"SXY`P*``$XX`P,``$[#DZ
MOSU5N10`$T$1L#B2@!``ISH``>/P_V#_<;D4`!.Y!`"B01&P.*<^`#BGQ`!<
MIT@`0+GY,"090Z>$``^G*O__ZS(`"`#>$C.G=`!ON18`(L8@````=[D$`"O`
MY?__\TO7-[`XL#CK&``8``Q"$+!P0H"P<^L8`!``#$(0L'%"D+!WZQD`&``,
M0A"P=+D$`"OK&0`0``Q"$+!UZX@`"``,0H"P<NN9``@`#$*0L';`Y?__\R&Y
M!``KT@.@`+`$T@.@!+`,T@.@"+`4T@.@#+`<T@.@$+`DZX_PX``$P/3__^%4
MIT@`.+GY,"090Z>$_[VG*O__ZS(`"`#>$C.G=``)N18`(L8@````(*?T_Z[C
M(!0``#;7_Q``$`!!$!$`IS;_^*?T_^_C(!0``#;7_Q``$`!!$!$`IS;_^*?T
M_XG7`!``$`#7`!``$``'!P<'!P?K?_`X`"3C\/]@_W&Y!`"2N00`@[D$`'3`
ML```*2C`Y?__W>7`$```*2*Y"0"QZ[L``P`*N0(`NZ>$`!*Y!`"AXQ"@```$
MN00`1Z>K``BY!``XN00`*0WAI[?_].M_\-@`!`?^!P<'!P?^!P<'!P<'Q%@`
M`#$`P/3__]Z/!P<'!\08```H]*<?__\'CNN_\%@`)./P_V#_<<"P```HZ..P
MO_C_<0WAXQ"P```$IQ___Z=T__?KO_#X``0'_@<'!P?K[_!P`"3C\/]@_W'K
M[_$0``0'_@<'!P?K;_`P`"2Y!``?I_O_8.,0\```),#````IM@<'P.7__^*>
M!P?C0/$0``3K;_#0``0']`<'``(``25S+R5S`"]P<F]C+W-E;&8O97AE``!$
M>6YA3&]A9&5R.CIB;V]T7T1Y;F%,;V%D97(`26YT97)N86QS.CI005(Z.D)/
M3U0``"]P<F]C+R5I+R5S`&5X90`N`%!!4E]414U0``!005)?4%)/1TY!344`
M`#H`+P!015),-4Q)0@``4$523$Q)0@!015),-4]05```4$523$E/``!005)?
M24Y)5$E!3$E:140`4$%27U-005=.140`4$%27T-,14%.`%!!4E]$14)51P!0
M05)?0T%#2$4`4$%27T=,3T)!3%]$14)51P``4$%27T=,3T)!3%]435!$25(`
M4$%27U1-4$1)4@``4$%27T=,3T)!3%]414U0`%!!4E]'3$]"04Q?0TQ%04X`
M`%!!4E]#3$5!3CT``#$`3$1?3$E"4D%265]0051(`%-94U1%30``)3`R>```
M)7,E<R5S)7,``'!A<BT``"5S.B!C<F5A=&EO;B!O9B!P<FEV871E('-U8F1I
M<F5C=&]R>2`E<R!F86EL960@*&5R<FYO/25I*0H``"5S.B!P<FEV871E('-U
M8F1I<F5C=&]R>2`E<R!I<R!U;G-A9F4@*'!L96%S92!R96UO=F4@:70@86YD
M(')E=')Y('EO=7(@;W!E<F%T:6]N*0H``%!!5$@``'!A<FP``"YP87(``"5S
M)7-C86-H92TE<R5S```E<R5S=&5M<"TE=25S`"5S)7-T96UP+25U+25U)7,`
M`!@`<&5R;```,`!005(Z.E!A8VME<CHZ5D524TE/3@``,2XP-30`56YA8FQE
M('1O(&-R96%T92!C86-H92!D:7)E8W1O<GD``"5S.B!C<F5A=&EO;B!O9B!P
M<FEV871E(&-A8VAE('-U8F1I<F5C=&]R>2`E<R!F86EL960@*&5R<FYO/25I
M*0H``"UE```M+0``55-%4@``55-%4DY!344``%1%35!$25(`5$U0`"]T;7``
M`&5V86P@)V5X96,@+W5S<B]B:6XO<&5R;"`@+5,@)#`@)'LQ*R(D0")])PII
M9B`P.R`C(&YO="!R=6YN:6YG('5N9&5R('-O;64@<VAE;&P*<&%C:V%G92!?
M7W!A<E]P;#L*;7D@*"1005)?34%'24,L("1P87)?=&5M<"P@)'!R;V=N86UE
M+"!`=&UP9FEL92P@)4UO9'5L94-A8VAE*3L*14Y$('L@:68@*"1%3E9[4$%2
M7T-,14%.?2D@>PIR97%U:7)E($9I;&4Z.E1E;7`["G)E<75I<F4@1FEL93HZ
M0F%S96YA;64["G)E<75I<F4@1FEL93HZ4W!E8SL*;7D@)'1O<&1I<B`]($9I
M;&4Z.D)A<V5N86UE.CID:7)N86UE*"1P87)?=&5M<"D["F]U=',H<7%;4F5M
M;W9I;F<@9FEL97,@:6X@(B1P87)?=&5M<")=*3L*1FEL93HZ1FEN9#HZ9FEN
M9&1E<'1H*'-U8B![("@@+60@*2`_(')M9&ER(#H@=6YL:6YK('TL("1P87)?
M=&5M<"D["G)M9&ER("1P87)?=&5M<#L*:68@*"UD("1P87)?=&5M<"`F)B`D
M7D\@;F4@)TU35VEN,S(G*2!["FUY("1T;7`@/2!N97<@1FEL93HZ5&5M<"@*
M5$5-4$Q!5$4@/3X@)W1M<%A86%A8)RP*1$E2(#T^($9I;&4Z.D)A<V5N86UE
M.CID:7)N86UE*"1T;W!D:7(I+`I3549&25@@/3X@)RYC;60G+`I53DQ)3DL@
M/3X@,"P**3L*;7D@)&9I;&5N86UE(#T@)'1M<"T^9FEL96YA;64["G!R:6YT
M("1T;7`@/#PB+BXN(CL*>#TQ.R!W:&EL92!;(%PD>"`M;'0@,3`@73L@9&\*
M<FT@+7)F("<D<&%R7W1E;7`G"FEF(%L@7"$@+60@)R1P87)?=&5M<"<@73L@
M=&AE;@IB<F5A:PIF:0IS;&5E<"`Q"G@]8&5X<'(@7"1X("L@,6`*9&]N90IR
M;2`G)&9I;&5N86UE)PHN+BX*8VQO<V4@)'1M<#L*8VAM;V0@,#<P,"P@)&9I
M;&5N86UE.PIM>2`D8VUD(#T@(B1F:6QE;F%M92`^+V1E=B]N=6QL(#(^)C$@
M)B(["G-Y<W1E;2@D8VUD*3L*;W5T<RAQ<5M3<&%W;F5D(&)A8VMG<F]U;F0@
M<')O8V5S<R!T;R!P97)F;W)M(&-L96%N=7`Z("1F:6QE;F%M95TI.PI]"GT@
M?0I"14=)3B!["B1005)?34%'24,@/2`B7&Y005(N<&U<;B(["DEN=&5R;F%L
M<SHZ4$%2.CI"3T]4*"D@:68@9&5F:6YE9"`F26YT97)N86QS.CI005(Z.D)/
M3U0["F5V86P@>PI?<&%R7VEN:71?96YV*"D["FUY("1Q=6EE="`]("$D14Y6
M>U!!4E]$14)51WT["FUY("5S>7,@/2`H"G!A=&A?<V5P("`@(#T^("@D7D\@
M/7X@+UY-4U=I;B\@/R`G.R<@.B`G.B<I+`I?97AE("`@("`@("`]/B`H)%Y/
M(#U^("]>*#\Z35-7:6Y\3U,R?&-Y9W=I;BDO(#\@)RYE>&4G(#H@)R<I+`I?
M9&5L:6T@("`@("`]/B`H)%Y/(#U^("]>35-7:6Y\3U,R+R`_("=<7"<@.B`G
M+R<I+`HI.PI?<V5T7W!R;V=N86UE*"D["F]U=',H<7%;7"1P<F]G;F%M92`]
M("(D<')O9VYA;64B72D["E]S971?<&%R7W1E;7`H*3L*;W5T<RAQ<5M<)$5.
M5GM005)?5$5-4'T@/2`B)$5.5GM005)?5$5-4'TB72D["FUY("@D<W1A<G1?
M<&]S+"`D9&%T85]P;W,I.PI-04=)0SH@>PIL;V-A;"`D4TE'>U]?5T%23E]?
M?2`]('-U8B![?3L*=6YL97-S("AO<&5N(%]&2"P@)SPZ<F%W)RP@)'!R;V=N
M86UE*2!["F]U=',H<7%;0V%N)W0@<F5A9"!F<F]M(&9I;&4@(B1P<F]G;F%M
M92)=*3L@(",@9&]N)W0@=7-E("0A(&AE<F4@87,@:70@<F5Q=6ER97,@17)R
M;F\N<&T*;&%S="!-04=)0SL*?0IM>2`D8VAU;FM?<VEZ92`](#8T("H@,3`R
M-#L*;7D@)&)U9CL*;7D@)'-I>F4@/2`M<R!?1D@["FUY("1M86=I8U]P;W,@
M/2`D<VEZ92`M("1S:7IE("4@)&-H=6YK7W-I>F4[(",@3D]413H@)&UA9VEC
M7W!O<R!I<R!A(&UU;'1I<&QE(&]F("1C:'5N:U]S:7IE"G=H:6QE("@D;6%G
M:6-?<&]S(#X](#`I('L*<V5E:R!?1D@L("1M86=I8U]P;W,L(#`["G)E860@
M7T9(+"`D8G5F+"`D8VAU;FM?<VEZ92`K(&QE;F=T:"@D4$%27TU!1TE#*3L*
M:68@*"AM>2`D:2`](')I;F1E>"@D8G5F+"`D4$%27TU!1TE#*2D@/CT@,"D@
M>PHD;6%G:6-?<&]S("L]("1I.PIL87-T.PI]"B1M86=I8U]P;W,@+3T@)&-H
M=6YK7W-I>F4["GT*:68@*"1M86=I8U]P;W,@/"`P*2!["F]U=',H<7%;0V%N
M)W0@9FEN9"!M86=I8R!S=')I;F<@(B1005)?34%'24,B(&EN(&9I;&4@(B1P
M<F]G;F%M92)=*3L*;&%S="!-04=)0SL*?0IS965K(%]&2"P@)&UA9VEC7W!O
M<R`M(#0L(#`["G)E860@7T9(+"`D8G5F+"`T.PIS965K(%]&2"P@)&UA9VEC
M7W!O<R`M(#0@+2!U;G!A8VLH(DXB+"`D8G5F*2P@,#L*)&1A=&%?<&]S(#T@
M=&5L;"!?1D@["FUY("5R97%U:7)E7VQI<W0["G)E860@7T9(+"`D8G5F+"`T
M.R`@("`@("`@("`@("`@("`@("`@("`@("`@(",@<F5A9"!T:&4@9FER<W0@
M(D9)3$4B"G=H:6QE("@D8G5F(&5Q(")&24Q%(BD@>PIR96%D(%]&2"P@)&)U
M9BP@-#L*<F5A9"!?1D@L("1B=68L('5N<&%C:R@B3B(L("1B=68I.PIM>2`D
M9G5L;&YA;64@/2`D8G5F.PIO=71S*'%Q6U5N<&%C:VEN9R!&24Q%("(D9G5L
M;&YA;64B+BXN72D["FUY("1C<F,@/2`H("1F=6QL;F%M92`]?B!S?%XH6V$M
M9EQD77LX?2DO?'P@*2`_("0Q(#H@=6YD968["FUY("@D8F%S96YA;64L("1E
M>'0I(#T@*"1B=68@/7X@;7PH/SHN*B\I/R@N*BDH7"XN*BE\*3L*<F5A9"!?
M1D@L("1B=68L(#0["G)E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F
M*3L*:68@*&1E9FEN960H)&5X="D@86YD("1E>'0@(7X@+UPN*#\Z<&U\<&Q\
M:7A\86PI)"]I*2!["FUY("1F:6QE;F%M92`](%]S879E7V%S*"(D8W)C)&5X
M="(L("1B=68L(#`W-34I.PHD4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F=6QL
M;F%M97T@/2`D9FEL96YA;64["B1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&9I
M;&5N86UE?2`]("1F=6QL;F%M93L*?0IE;'-I9B`H("1F=6QL;F%M92`]?B!M
M?%XO/W-H;&EB+WP@86YD(&1E9FEN960@)$5.5GM005)?5$5-4'T@*2!["FUY
M("1F:6QE;F%M92`](%]S879E7V%S*"(D8F%S96YA;64D97AT(BP@)&)U9BP@
M,#<U-2D["F]U=',H(E-(3$E".B`D9FEL96YA;65<;B(I.PI]"F5L<V4@>PHD
M36]D=6QE0V%C:&5[)&9U;&QN86UE?2`]('L*8G5F(#T^("1B=68L"F-R8R`]
M/B`D8W)C+`IN86UE(#T^("1F=6QL;F%M92P*?3L*)')E<75I<F5?;&ES='LD
M9G5L;&YA;65]*RL["GT*<F5A9"!?1D@L("1B=68L(#0["GT*;&]C86P@0$E.
M0R`]("AS=6(@>PIM>2`H)'-E;&8L("1M;V1U;&4I(#T@0%\["G)E='5R;B!I
M9B!R968@)&UO9'5L92!O<B`A)&UO9'5L93L*;7D@)&EN9F\@/2`D36]D=6QE
M0V%C:&5[)&UO9'5L97T["G)E='5R;B!U;FQE<W,@)&EN9F\["F1E;&5T92`D
M<F5Q=6ER95]L:7-T>R1M;V1U;&5].PHD24Y#>R1M;V1U;&5](#T@(B]L;V%D
M97(O)&EN9F\O)&UO9'5L92(["FEF("@D14Y6>U!!4E]#3$5!3GT@86YD(&1E
M9FEN960H)DE/.CI&:6QE.CIN97<I*2!["FUY("1F:"`]($E/.CI&:6QE+3YN
M97=?=&UP9FEL92!O<B!D:64@(D-A;B=T(&-R96%T92!T96UP(&9I;&4Z("0A
M(CL*)&9H+3YB:6YM;V1E*"D["B1F:"T^<')I;G0H)&EN9F\M/GMB=69]*3L*
M)&9H+3YS965K*#`L(#`I.PIR971U<FX@)&9H.PI]"F5L<V4@>PIM>2`D9FEL
M96YA;64@/2!?<V%V95]A<R@B)&EN9F\M/GMC<F-]+G!M(BP@)&EN9F\M/GMB
M=69]*3L*)&EN9F\M/GMF:6QE?2`]("1F:6QE;F%M93L*;W!E;B!M>2`D9F@L
M("<\.G)A=R<L("1F:6QE;F%M92!O<B!D:64@<7%;0V%N)W0@<F5A9"`B)&9I
M;&5N86UE(CH@)"%=.PIR971U<FX@)&9H.PI]"F1I92`B0F]O='-T<F%P<&EN
M9R!F86EL960Z(&-A;B=T(&9I;F0@;6]D=6QE("1M;V1U;&4A(CL*?2P@0$E.
M0RD["G)E<75I<F4@6%-,;V%D97(["G)E<75I<F4@4$%2.CI(96%V>3L*<F5Q
M=6ER92!#87)P.CI(96%V>3L*<F5Q=6ER92!%>'!O<G1E<CHZ2&5A=GD["E!!
M4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*<F5Q=6ER92!)3SHZ1FEL
M93L*=VAI;&4@*&UY("1F:6QE;F%M92`]("AS;W)T(&ME>7,@)7)E<75I<F5?
M;&ES="E;,%TI('L*=6YL97-S("@D24Y#>R1F:6QE;F%M97T@;W(@)&9I;&5N
M86UE(#U^("]"4T1004XO*2!["FEF("@D9FEL96YA;64@/7X@+UPN<&UC/R0O
M:2D@>PIR97%U:7)E("1F:6QE;F%M93L*?0IE;'-E('L*9&\@)&9I;&5N86UE
M('5N;&5S<R`D9FEL96YA;64@/7X@+W-I=&5C=7-T;VUI>F5<+G!L)"\["GT*
M?0ID96QE=&4@)')E<75I<F5?;&ES='LD9FEL96YA;65].PI]"G5N;&5S<R`H
M)&)U9B!E<2`B4$M<,#`S7#`P-"(I('L*;W5T<RAQ<5M.;R!Z:7`@9F]U;F0@
M869T97(@1DE,12!S96-T:6]N(&EN(&9I;&4@(B1P<F]G;F%M92)=*3L*;&%S
M="!-04=)0R`["GT*)'-T87)T7W!O<R`]("AT96QL(%]&2"D@+2`T.R`@("`@
M("`@("`@("`@("`C('-T87)T(&]F('II<`I]"FUY($!P87)?87)G<SL*;7D@
M*"1O=70L("1B=6YD;&4L("1L;V=F:"P@)&-A8VAE7VYA;64I.PID96QE=&4@
M)$5.5GM005)?05!07U)%55-%?3L@(R!S86YI=&EZ92`H4D554T4@;6%Y(&)E
M(&$@<V5C=7)I='D@<')O8FQE;2D*)'%U:65T(#T@,"!U;FQE<W,@)$5.5GM0
M05)?1$5"54=].PII9B`H(21S=&%R=%]P;W,@;W(@*"1!4D=66S!=(&5Q("<M
M+7!A<BUO<'1I;VYS)R`F)B!S:&EF="DI('L*;7D@)61I<W1?8VUD(#T@<7<H
M"G`@("!B;&EB7W1O7W!A<@II("`@:6YS=&%L;%]P87(*=2`@('5N:6YS=&%L
M;%]P87(*<R`@('-I9VY?<&%R"G8@("!V97)I9GE?<&%R"BD["FEF("A`05)'
M5B!A;F0@)$%21U9;,%T@97$@)RTM<F5U<V4G*2!["G-H:69T($!!4D=6.PHD
M14Y6>U!!4E]!4%!?4D554T5](#T@<VAI9G0@0$%21U8["GT*96QS92![(",@
M;F]R;6%L('!A<FP@8F5H879I;W5R"FUY($!A9&1?=&]?:6YC.PIW:&EL92`H
M0$%21U8I('L*)$%21U9;,%T@/7X@+UXM*%M!24U/0DQB<7!I=7-4=ETI*"XJ
M*2\@;W(@;&%S=#L*:68@*"0Q(&5Q("=))RD@>PIP=7-H($!A9&1?=&]?:6YC
M+"`D,CL*?0IE;'-I9B`H)#$@97$@)TTG*2!["F5V86P@(G5S92`D,B(["GT*
M96QS:68@*"0Q(&5Q("=!)RD@>PIU;G-H:69T($!P87)?87)G<RP@)#(["GT*
M96QS:68@*"0Q(&5Q("=/)RD@>PHD;W5T(#T@)#(["GT*96QS:68@*"0Q(&5Q
M("=B)RD@>PHD8G5N9&QE(#T@)W-I=&4G.PI]"F5L<VEF("@D,2!E<2`G0B<I
M('L*)&)U;F1L92`]("=A;&PG.PI]"F5L<VEF("@D,2!E<2`G<2<I('L*)'%U
M:65T(#T@,3L*?0IE;'-I9B`H)#$@97$@)TPG*2!["F]P96X@)&QO9V9H+"`B
M/CXB+"`D,B!O<B!D:64@<7%;0V%N)W0@;W!E;B!L;V<@9FEL92`B)#(B.B`D
M(5T["GT*96QS:68@*"0Q(&5Q("=4)RD@>PHD8V%C:&5?;F%M92`]("0R.PI]
M"G-H:69T*$!!4D=6*3L*:68@*&UY("1C;60@/2`D9&ES=%]C;61[)#%]*2![
M"F1E;&5T92`D14Y6>R=005)?5$5-4"=].PII;FET7VEN8R@I.PIR97%U:7)E
M(%!!4CHZ1&ES=#L*)GLB4$%2.CI$:7-T.CHD8VUD(GTH*2!U;FQE<W,@0$%2
M1U8["B9[(E!!4CHZ1&ES=#HZ)&-M9")]*"1?*2!F;W(@0$%21U8["F5X:70[
M"GT*?0IU;G-H:69T($!)3D,L($!A9&1?=&]?:6YC.PI]"GT*:68@*"1O=70I
M('L*>PIR97%U:7)E($E/.CI&:6QE.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*
M<F5Q=6ER92!$:6=E<W0Z.E-(03L*?0IM>2`D<&%R(#T@<VAI9G0H0$%21U8I
M.PIM>2`D>FEP.PII9B`H9&5F:6YE9"`D<&%R*2!["F]P96X@;7D@)&9H+"`G
M/#IR87<G+"`D<&%R(&]R(&1I92!Q<5M#86XG="!F:6YD('!A<B!F:6QE("(D
M<&%R(CH@)"%=.PIB;&5S<R@D9F@L("=)3SHZ1FEL92<I.PHD>FEP(#T@07)C
M:&EV93HZ6FEP+3YN97<["B@@)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F
M:"P@)'!A<BD@/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I("D*;W(@9&EE('%Q
M6T5R<F]R(')E861I;F<@>FEP(&%R8VAI=F4@(B1P87(B73L*?0IM>2`E96YV
M(#T@9&\@>PII9B`H)'II<"!A;F0@;7D@)&UE=&$@/2`D>FEP+3YC;VYT96YT
M<R@G345402YY;6PG*2D@>PHD;65T82`]?B!S+RXJ7G!A<CHD+R]M<SL*)&UE
M=&$@/7X@<R]>7%,N*B\O;7,["B1M971A(#U^("]>("`H6UXZ72LI.B`H+BLI
M)"]M9SL*?0I].PII9B`H9&5F:6YE9"`D<&%R*2!["F]P96X@;7D@)'!H+"`G
M/#IR87<G+"`D<&%R(&]R(&1I92!Q<5M#86XG="!R96%D('!A<B!F:6QE("(D
M<&%R(CH@)"%=.PIM>2`D8G5F.PIR96%D("1P:"P@)&)U9BP@-#L*9&EE('%Q
M6R(D<&%R(B!I<R!N;W0@82!P87(@9FEL95T@=6YL97-S("1B=68@97$@(E!+
M7#`P,UPP,#0B.PIC;&]S92`D<&@["GT*0W)E871E4&%T:"@D;W5T*2`["FUY
M("1F:"`]($E/.CI&:6QE+3YN97<H"B1O=70L"DE/.CI&:6QE.CI/7T-214%4
M*"D@?"!)3SHZ1FEL93HZ3U]74D].3%DH*2!\($E/.CI&:6QE.CI/7U1254Y#
M*"DL"C`W-S<L"BD@;W(@9&EE('%Q6T-A;B=T(&-R96%T92!F:6QE("(D;W5T
M(CH@)"%=.PHD9F@M/F)I;FUO9&4H*3L*<V5E:R!?1D@L(#`L(#`["FUY("1L
M;V%D97(["FEF("AD969I;F5D("1D871A7W!O<RD@>PIR96%D(%]&2"P@)&QO
M861E<BP@)&1A=&%?<&]S.PI](&5L<V4@>PIL;V-A;"`D+R`]('5N9&5F.PHD
M;&]A9&5R(#T@/%]&2#X["GT*:68@*"$D14Y6>U!!4E]615)"051)37T@86YD
M("1L;V%D97(@/7X@+UXH/SHC(7Q<0')E;2DO*2!["G)E<75I<F4@4$%2.CI&
M:6QT97(Z.E!O9%-T<FEP.PI005(Z.D9I;'1E<CHZ4&]D4W1R:7`M/F%P<&QY
M*%PD;&]A9&5R+"`D,"D["GT*9F]R96%C:"!M>2`D:V5Y("AS;W)T(&ME>7,@
M)65N=BD@>PIM>2`D=F%L(#T@)&5N=GLD:V5Y?2!O<B!N97AT.PHD=F%L(#T@
M979A;"`D=F%L(&EF("1V86P@/7X@+UY;)R)=+SL*;7D@)&UA9VEC(#T@(E]?
M14Y67U!!4E\B("X@=6,H)&ME>2D@+B`B7U\B.PIM>2`D<V5T(#T@(E!!4E\B
M("X@=6,H)&ME>2D@+B`B/21V86PB.PHD;&]A9&5R(#U^('-[)&UA9VEC*"`K
M*7U["B1M86=I8R`N("1S970@+B`H)R`G('@@*&QE;F=T:"@D,2D@+2!L96YG
M=&@H)'-E="DI*0I]96<["GT*)&9H+3YP<FEN="@D;&]A9&5R*3L*:68@*"1B
M=6YD;&4I('L*<F5Q=6ER92!005(Z.DAE879Y.PI005(Z.DAE879Y.CI?:6YI
M=%]D>6YA;&]A9&5R*"D["FEN:71?:6YC*"D["G)E<75I<F5?;6]D=6QE<R@I
M.PIM>2!`:6YC(#T@9W)E<"![("$O0E-$4$%.+R!]"F=R97`@>PHH)&)U;F1L
M92!N92`G<VET92<I(&]R"B@D7R!N92`D0V]N9FEG.CI#;VYF:6=[87)C:&QI
M8F5X<'T@86YD"B1?(&YE("1#;VYF:6<Z.D-O;F9I9WMP<FEV;&EB97AP?2D[
M"GT@0$E.0SL*<WPO*WPO?&<L('-\+R1\?"!F;W)E86-H($!I;F,["FUY("5F
M:6QE<SL*)&9I;&5S>R1??2LK(&9O<B!`1'EN84QO861E<CHZ9&Q?<VAA<F5D
M7V]B:F5C=',L('9A;'5E<R`E24Y#.PIM>2`D;&EB7V5X="`]("1#;VYF:6<Z
M.D-O;F9I9WML:6)?97AT?3L@("`@("`@("`C(%A86"!L:6)?97AT('9S(&1L
M97AT(#\*;7D@)7=R:71T96X["F9O<F5A8V@@;7D@)&ME>2`H<V]R="!K97ES
M("5F:6QE<RD@>PIM>2`H)&9I;&4L("1N86UE*3L*:68@*&1E9FEN960H;7D@
M)&9C(#T@)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD:V5Y?2DI('L**"1F:6QE
M+"`D;F%M92D@/2`H)&ME>2P@)&9C*3L*?0IE;'-E('L*9F]R96%C:"!M>2`D
M9&ER("A`:6YC*2!["FEF("@D:V5Y(#U^(&U\7EQ1)&1I<EQ%+R@N*BDD?&DI
M('L**"1F:6QE+"`D;F%M92D@/2`H)&ME>2P@)#$I.PIL87-T.PI]"FEF("@D
M:V5Y(#U^(&U\7B]L;V%D97(O6UXO72LO*"XJ*21\*2!["FEF("AM>2`D<F5F
M(#T@)$UO9'5L94-A8VAE>R0Q?2D@>PHH)&9I;&4L("1N86UE*2`]("@D<F5F
M+"`D,2D["FQA<W0["GT*:68@*"UF("(D9&ER+R0Q(BD@>PHH)&9I;&4L("1N
M86UE*2`]("@B)&1I<B\D,2(L("0Q*3L*;&%S=#L*?0I]"GT*?0IN97AT('5N
M;&5S<R!D969I;F5D("1N86UE.PIN97AT(&EF("1W<FET=&5N>R1N86UE?2LK
M.PIN97AT(&EF("%R968H)&9I;&4I(&%N9"`D9FEL92`]?B`O7"Y<421L:6)?
M97AT7$4D+VD["F]U=',H<W!R:6YT9BAQ<5M086-K:6YG($9)3$4@(B5S(BXN
M+ETL(')E9B`D9FEL92`_("1F:6QE+3Y[;F%M97T@.B`D9FEL92DI.PIM>2`D
M8V]N=&5N=#L*:68@*')E9B@D9FEL92DI('L*)&-O;G1E;G0@/2`D9FEL92T^
M>V)U9GT["GT*96QS92!["FQO8V%L("0O(#T@=6YD968["F]P96X@;7D@)&9H
M+"`G/#IR87<G+"`D9FEL92!O<B!D:64@<7%;0V%N)W0@<F5A9"`B)&9I;&4B
M.B`D(5T["B1C;VYT96YT(#T@/"1F:#X["F-L;W-E("1F:#L*4$%2.CI&:6QT
M97(Z.E!O9%-T<FEP+3YA<'!L>2A<)&-O;G1E;G0L("(\96UB961D960^+R1N
M86UE(BD*:68@(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@)&YA;64@/7X@+UPN
M*#\Z<&U\:7A\86PI)"]I.PI005(Z.D9I;'1E<CHZ4&%T8VA#;VYT96YT+3YN
M97<M/F%P<&QY*%PD8V]N=&5N="P@)&9I;&4L("1N86UE*3L*?0HD9F@M/G!R
M:6YT*")&24Q%(BP*<&%C:R@G3B<L(&QE;F=T:"@D;F%M92D@*R`Y*2P*<W!R
M:6YT9B@B)3`X>"\E<R(L($%R8VAI=F4Z.EII<#HZ8V]M<'5T94-20S,R*"1C
M;VYT96YT*2P@)&YA;64I+`IP86-K*"=.)RP@;&5N9W1H*"1C;VYT96YT*2DL
M"B1C;VYT96YT*3L*;W5T<RAQ<5M7<FET=&5N(&%S("(D;F%M92)=*3L*?0I]
M"B1Z:7`M/G=R:71E5&]&:6QE2&%N9&QE*"1F:"D@:68@)'II<#L*)&-A8VAE
M7VYA;64@/2!S=6)S='(@)&-A8VAE7VYA;64L(#`L(#0P.PII9B`H(21C86-H
M95]N86UE(&%N9"!M>2`D;71I;64@/2`H<W1A="@D;W5T*2E;.5TI('L*;7D@
M)&-T>"`]($1I9V5S=#HZ4TA!+3YN97<H,2D["F]P96X@;7D@)&9H+"`B/#IR
M87<B+"`D;W5T.PHD8W1X+3YA9&1F:6QE*"1F:"D["F-L;W-E("1F:#L*)&-A
M8VAE7VYA;64@/2`D8W1X+3YH97AD:6=E<W0["GT*)&-A8VAE7VYA;64@+CT@
M(EPP(B!X("@T,2`M(&QE;F=T:"`D8V%C:&5?;F%M92D["B1C86-H95]N86UE
M("X](")#04-(12(["B1F:"T^<')I;G0H)&-A8VAE7VYA;64I.PHD9F@M/G!R
M:6YT*'!A8VLH)TXG+"`D9F@M/G1E;&P@+2!L96YG=&@H)&QO861E<BDI*3L*
M)&9H+3YP<FEN="@D4$%27TU!1TE#*3L*)&9H+3YC;&]S93L*8VAM;V0@,#<U
M-2P@)&]U=#L*97AI=#L*?0I["FQA<W0@=6YL97-S(&1E9FEN960@)'-T87)T
M7W!O<SL*7V9I>%]P<F]G;F%M92@I.PIR97%U:7)E(%!!4CL*4$%2.CI(96%V
M>3HZ7VEN:71?9'EN86QO861E<B@I.PI["G)E<75I<F4@1FEL93HZ1FEN9#L*
M<F5Q=6ER92!!<F-H:79E.CI::7`["GT*;7D@)&9H(#T@24\Z.D9I;&4M/FYE
M=SL@("`@("`@("`@("`@("`@("`@("`@("`@("`@(",@07)C:&EV93HZ6FEP
M(&]P97)A=&5S(&]N(&%N($E/.CI(86YD;&4*)&9H+3YF9&]P96XH9FEL96YO
M*%]&2"DL("=R)RD@;W(@9&EE('%Q6V9D;W!E;B@I(&9A:6QE9#H@)"%=.PI!
M<F-H:79E.CI::7`Z.G-E=$-H=6YK4VEZ92@M<R!?1D@I.PIM>2`D>FEP(#T@
M07)C:&EV93HZ6FEP+3YN97<["B@@)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE
M*"1F:"P@)'!R;V=N86UE*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"D@*0IO
M<B!D:64@<7%;17)R;W(@<F5A9&EN9R!Z:7`@87)C:&EV92`B)'!R;V=N86UE
M(ET["D%R8VAI=F4Z.EII<#HZ<V5T0VAU;FM3:7IE*#8T("H@,3`R-"D["G!U
M<V@@0%!!4CHZ3&EB0V%C:&4L("1Z:7`["B1005(Z.DQI8D-A8VAE>R1P<F]G
M;F%M97T@/2`D>FEP.PHD<75I970@/2`A)$5.5GM005)?1$5"54=].PII9B`H
M9&5F:6YE9"`D14Y6>U!!4E]414U0?2D@>R`C('-H;W5L9"!B92!S970@870@
M=&AI<R!P;VEN="$*9F]R96%C:"!M>2`D;65M8F5R("@@)'II<"T^;65M8F5R
M<R`I('L*;F5X="!I9B`D;65M8F5R+3YI<T1I<F5C=&]R>3L*;7D@)&UE;6)E
M<E]N86UE(#T@)&UE;6)E<BT^9FEL94YA;64["FYE>'0@=6YL97-S("1M96UB
M97)?;F%M92`]?B!M>PI>"B\_<VAL:6(O"B@_.B1#;VYF:6<Z.D-O;F9I9WMV
M97)S:6]N?2\I/PHH/SHD0V]N9FEG.CI#;VYF:6=[87)C:&YA;65]+RD_"BA;
M7B]=*RD*)`I]>#L*;7D@)&5X=')A8W1?;F%M92`]("0Q.PIM>2`D9&5S=%]N
M86UE(#T@1FEL93HZ4W!E8RT^8V%T9FEL92@D14Y6>U!!4E]414U0?2P@)&5X
M=')A8W1?;F%M92D["FEF("@M9B`D9&5S=%]N86UE("8F("US(%\@/3T@)&UE
M;6)E<BT^=6YC;VUP<F5S<V5D4VEZ92@I*2!["F]U=',H<7%;4VMI<'!I;F<@
M(B1M96UB97)?;F%M92(@<VEN8V4@:70@86QR96%D>2!E>&ES=',@870@(B1D
M97-T7VYA;64B72D["GT@96QS92!["F]U=',H<7%;17AT<F%C=&EN9R`B)&UE
M;6)E<E]N86UE(B!T;R`B)&1E<W1?;F%M92)=*3L*)&UE;6)E<BT^97AT<F%C
M=%1O1FEL94YA;65D*"1D97-T7VYA;64I.PIC:&UO9"@P-34U+"`D9&5S=%]N
M86UE*2!I9B`D7D\@97$@(FAP=7@B.PI]"GT*?0I]"G5N;&5S<R`H)%!!4CHZ
M3&EB0V%C:&5[)'!R;V=N86UE?2D@>PID:64@/#P@(BXB('5N;&5S<R!`05)'
M5CL*57-A9V4Z("0P(%L@+4%L:6(N<&%R(%T@6R`M261I<B!=(%L@+4UM;V1U
M;&4@72!;('-R8RYP87(@72!;('!R;V=R86TN<&P@70HD,"!;("U"?"UB(%T@
M6RU/;W5T9FEL95T@<W)C+G!A<@HN"B1%3E9[4$%27U!23T=.04U%?2`]("1P
M<F]G;F%M92`]("0P(#T@<VAI9G0H0$%21U8I.PI]"G-U8B!#<F5A=&50871H
M('L*;7D@*"1N86UE*2`]($!?.PIR97%U:7)E($9I;&4Z.D)A<V5N86UE.PIM
M>2`H)&)A<V5N86UE+"`D<&%T:"P@)&5X="D@/2!&:6QE.CI"87-E;F%M93HZ
M9FEL97!A<G-E*"1N86UE+"`H)UPN+BHG*2D["G)E<75I<F4@1FEL93HZ4&%T
M:#L*1FEL93HZ4&%T:#HZ;6MP871H*"1P871H*2!U;FQE<W,H+64@)'!A=&@I
M.R`C(&UK<&%T:"!D:65S('=I=&@@97)R;W(*?0IS=6(@<F5Q=6ER95]M;V1U
M;&5S('L*<F5Q=6ER92!L:6(["G)E<75I<F4@1'EN84QO861E<CL*<F5Q=6ER
M92!I;G1E9V5R.PIR97%U:7)E('-T<FEC=#L*<F5Q=6ER92!W87)N:6YG<SL*
M<F5Q=6ER92!V87)S.PIR97%U:7)E($-A<G`["G)E<75I<F4@0V%R<#HZ2&5A
M=GD["G)E<75I<F4@17)R;F\["G)E<75I<F4@17AP;W)T97(Z.DAE879Y.PIR
M97%U:7)E($5X<&]R=&5R.PIR97%U:7)E($9C;G1L.PIR97%U:7)E($9I;&4Z
M.E1E;7`["G)E<75I<F4@1FEL93HZ4W!E8SL*<F5Q=6ER92!84TQO861E<CL*
M<F5Q=6ER92!#;VYF:6<["G)E<75I<F4@24\Z.DAA;F1L93L*<F5Q=6ER92!)
M3SHZ1FEL93L*<F5Q=6ER92!#;VUP<F5S<SHZ6FQI8CL*<F5Q=6ER92!!<F-H
M:79E.CI::7`["G)E<75I<F4@1&EG97-T.CI32$$["G)E<75I<F4@4$%2.PIR
M97%U:7)E(%!!4CHZ2&5A=GD["G)E<75I<F4@4$%2.CI$:7-T.PIR97%U:7)E
M(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ
M4&%T8VA#;VYT96YT.PIR97%U:7)E(&%T=')I8G5T97,["F5V86P@>R!R97%U
M:7)E($-W9"!].PIE=F%L('L@<F5Q=6ER92!7:6XS,B!].PIE=F%L('L@<F5Q
M=6ER92!38V%L87(Z.E5T:6P@?3L*979A;"![(')E<75I<F4@07)C:&EV93HZ
M56YZ:7`Z.D)U<G-T('T["F5V86P@>R!R97%U:7)E(%1I93HZ2&%S:#HZ3F%M
M961#87!T=7)E('T["F5V86P@>R!R97%U:7)E(%!E<FQ)3SL@<F5Q=6ER92!0
M97)L24\Z.G-C86QA<B!].PIE=F%L('L@<F5Q=6ER92!U=&8X('T["GT*<W5B
M(%]S971?<&%R7W1E;7`@>PII9B`H9&5F:6YE9"`D14Y6>U!!4E]414U0?2!A
M;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO*2!["B1P87)?=&5M<"`]("0Q
M.PIR971U<FX["GT*9F]R96%C:"!M>2`D<&%T:"`H"BAM87`@)$5.5GLD7WTL
M('%W*"!005)?5$U01$E2(%1-4$1)4B!414U01$E2(%1%35`@5$U0("DI+`IQ
M=R@@0SI<7%1%35`@+W1M<"`N("D**2!["FYE>'0@=6YL97-S(&1E9FEN960@
M)'!A=&@@86YD("UD("1P871H(&%N9"`M=R`D<&%T:#L*;7D@)'5S97)N86UE
M.PIM>2`D<'=U:60["F5V86P@>R@D<'=U:60I(#T@9V5T<'=U:60H)#XI(&EF
M(&1E9FEN960@)#X[?3L*:68@*"!D969I;F5D*"97:6XS,CHZ3&]G:6Y.86UE
M*2`I('L*)'5S97)N86UE(#T@)E=I;C,R.CI,;V=I;DYA;64["GT*96QS:68@
M*&1E9FEN960@)'!W=6ED*2!["B1U<V5R;F%M92`]("1P=W5I9#L*?0IE;'-E
M('L*)'5S97)N86UE(#T@)$5.5GM54T523D%-17T@?'P@)$5.5GM54T52?2!\
M?"`G4UE35$5-)SL*?0HD=7-E<FYA;64@/7X@<R]<5R]?+V<["FUY("1S=&UP
M9&ER(#T@(B1P871H)'-Y<WM?9&5L:6U]<&%R+2(N=6YP86-K*")(*B(L("1U
M<V5R;F%M92D["FUK9&ER("1S=&UP9&ER+"`P-S4U.PII9B`H(21%3E9[4$%2
M7T-,14%.?2!A;F0@;7D@)&UT:6UE(#T@*'-T870H)'!R;V=N86UE*2E;.5TI
M('L*;W!E;B!M>2`D9F@L("(\.G)A=R(L("1P<F]G;F%M92!O<B!D:64@<7%;
M0V%N)W0@<F5A9"`B)'!R;V=N86UE(CH@)"%=.PIS965K("1F:"P@+3$X+"`R
M.PIM>2`D8G5F.PIR96%D("1F:"P@)&)U9BP@-CL*:68@*"1B=68@97$@(EPP
M0T%#2$4B*2!["G-E96L@)&9H+"`M-3@L(#(["G)E860@)&9H+"`D8G5F+"`T
M,3L*)&)U9B`]?B!S+UPP+R]G.PHD<W1M<&1I<B`N/2`B)'-Y<WM?9&5L:6U]
M8V%C:&4M)&)U9B(["GT*96QS92!["FUY("1D:6=E<W0@/2!E=F%L"GL*<F5Q
M=6ER92!$:6=E<W0Z.E-(03L*;7D@)&-T>"`]($1I9V5S=#HZ4TA!+3YN97<H
M,2D["F]P96X@;7D@)&9H+"`B/#IR87<B+"`D<')O9VYA;64@;W(@9&EE('%Q
M6T-A;B=T(')E860@(B1P<F]G;F%M92(Z("0A73L*)&-T>"T^861D9FEL92@D
M9F@I.PIC;&]S92@D9F@I.PHD8W1X+3YH97AD:6=E<W0["GT@?'P@)&UT:6UE
M.PHD<W1M<&1I<B`N/2`B)'-Y<WM?9&5L:6U]8V%C:&4M)&1I9V5S="(["GT*
M8VQO<V4H)&9H*3L*?0IE;'-E('L*)$5.5GM005)?0TQ%04Y](#T@,3L*)'-T
M;7!D:7(@+CT@(B1S>7-[7V1E;&EM?71E;7`M)"0B.PI]"B1%3E9[4$%27U1%
M35!](#T@)'-T;7!D:7(["FUK9&ER("1S=&UP9&ER+"`P-S4U.PIL87-T.PI]
M"B1P87)?=&5M<"`]("0Q(&EF("1%3E9[4$%27U1%35!](&%N9"`D14Y6>U!!
M4E]414U0?2`]?B`O*"XK*2\["GT*<W5B(%]S879E7V%S('L*;7D@*"1N86UE
M+"`D8V]N=&5N=',L("1M;V1E*2`]($!?.PIM>2`D9G5L;&YA;64@/2`B)'!A
M<E]T96UP+R1N86UE(CL*=6YL97-S("@M92`D9G5L;&YA;64I('L*;7D@)'1E
M;7!N86UE(#T@(B1F=6QL;F%M92XD)"(["F]P96X@;7D@)&9H+"`G/CIR87<G
M+"`D=&5M<&YA;64@;W(@9&EE('%Q6T-A;B=T('=R:71E("(D=&5M<&YA;64B
M.B`D(5T["G!R:6YT("1F:"`D8V]N=&5N=',["F-L;W-E("1F:#L*8VAM;V0@
M)&UO9&4L("1T96UP;F%M92!I9B!D969I;F5D("1M;V1E.PIR96YA;64H)'1E
M;7!N86UE+"`D9G5L;&YA;64I(&]R('5N;&EN:R@D=&5M<&YA;64I.PI]"G)E
M='5R;B`D9G5L;&YA;64["GT*<W5B(%]S971?<')O9VYA;64@>PII9B`H9&5F
M:6YE9"`D14Y6>U!!4E]04D]'3D%-17T@86YD("1%3E9[4$%27U!23T=.04U%
M?2`]?B`O*"XK*2\I('L*)'!R;V=N86UE(#T@)#$["GT*)'!R;V=N86UE('Q\
M/2`D,#L*:68@*"1%3E9[4$%27U1%35!](&%N9"!I;F1E>"@D<')O9VYA;64L
M("1%3E9[4$%27U1%35!]*2`^/2`P*2!["B1P<F]G;F%M92`]('-U8G-T<B@D
M<')O9VYA;64L(')I;F1E>"@D<')O9VYA;64L("1S>7-[7V1E;&EM?2D@*R`Q
M*3L*?0II9B`H(21%3E9[4$%27U!23T=.04U%?2!O<B!I;F1E>"@D<')O9VYA
M;64L("1S>7-[7V1E;&EM?2D@/CT@,"D@>PII9B`H;W!E;B!M>2`D9F@L("<\
M)RP@)'!R;V=N86UE*2!["G)E='5R;B!I9B`M<R`D9F@["GT*:68@*"US("(D
M<')O9VYA;64D<WES>U]E>&5](BD@>PHD<')O9VYA;64@+CT@)'-Y<WM?97AE
M?3L*<F5T=7)N.PI]"GT*9F]R96%C:"!M>2`D9&ER("AS<&QI="`O7%$D<WES
M>W!A=&A?<V5P?5Q%+RP@)$5.5GM0051(?2D@>PIN97AT(&EF(&5X:7-T<R`D
M14Y6>U!!4E]414U0?2!A;F0@)&1I<B!E<2`D14Y6>U!!4E]414U0?3L*)&1I
M<B`]?B!S+UQ1)'-Y<WM?9&5L:6U]7$4D+R\["B@H)'!R;V=N86UE(#T@(B1D
M:7(D<WES>U]D96QI;7TD<')O9VYA;64D<WES>U]E>&5](BDL(&QA<W0I"FEF
M("US("(D9&ER)'-Y<WM?9&5L:6U])'!R;V=N86UE)'-Y<WM?97AE?2(["B@H
M)'!R;V=N86UE(#T@(B1D:7(D<WES>U]D96QI;7TD<')O9VYA;64B*2P@;&%S
M="D*:68@+7,@(B1D:7(D<WES>U]D96QI;7TD<')O9VYA;64B.PI]"GT*<W5B
M(%]F:7A?<')O9VYA;64@>PHD,"`]("1P<F]G;F%M92!\?#T@)$5.5GM005)?
M4%)/1TY!345].PII9B`H:6YD97@H)'!R;V=N86UE+"`D<WES>U]D96QI;7TI
M(#P@,"D@>PHD<')O9VYA;64@/2`B+B1S>7-[7V1E;&EM?21P<F]G;F%M92([
M"GT*;7D@)'!W9"`]("AD969I;F5D("9#=V0Z.F=E=&-W9"D@/R!#=V0Z.F=E
M=&-W9"@I"CH@*"AD969I;F5D("97:6XS,CHZ1V5T0W=D*2`_(%=I;C,R.CI'
M971#=V0H*2`Z(&!P=V1@*3L*8VAO;7`H)'!W9"D["B1P<F]G;F%M92`]?B!S
M+UXH/SU<+EPN/UQ1)'-Y<WM?9&5L:6U]7$4I+R1P=V0D<WES>U]D96QI;7TO
M.PHD14Y6>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64["GT*<W5B(%]P87)?
M:6YI=%]E;G8@>PII9B`H("1%3E9[4$%27TE.251)04Q)6D5$?2LK(#T](#$@
M*2!["G)E='5R;CL*?2!E;'-E('L*)$5.5GM005)?24Y)5$E!3$E:141](#T@
M,CL*?0IF;W(@*'%W*"!34$%73D5$(%1%35`@0TQ%04X@1$5"54<@0T%#2$4@
M4%)/1TY!344@*2`I('L*9&5L971E("1%3E9[)U!!4E\G+B1??3L*?0IF;W(@
M*'%W+R!435!$25(@5$5-4"!#3$5!3B!$14)51R`O*2!["B1%3E9[)U!!4E\G
M+B1??2`]("1%3E9[)U!!4E]'3$]"04Q?)RXD7WT@:68@97AI<W1S("1%3E9[
M)U!!4E]'3$]"04Q?)RXD7WT["GT*;7D@)'!A<E]C;&5A;B`](")?7T5.5E]0
M05)?0TQ%04Y?7R`@("`@("`@("`@("`@("(["FEF("@D14Y6>U!!4E]414U0
M?2D@>PID96QE=&4@)$5.5GM005)?0TQ%04Y].PI]"F5L<VEF("@A97AI<W1S
M("1%3E9[4$%27T=,3T)!3%]#3$5!3GTI('L*;7D@)'9A;'5E(#T@<W5B<W1R
M*"1P87)?8VQE86XL(#$R("L@;&5N9W1H*")#3$5!3B(I*3L*)$5.5GM005)?
M0TQ%04Y](#T@)#$@:68@)'9A;'5E(#U^("]>4$%27T-,14%./2A<4RLI+SL*
M?0I]"G-U8B!O=71S('L*<F5T=7)N(&EF("1Q=6EE=#L*:68@*"1L;V=F:"D@
M>PIP<FEN="`D;&]G9F@@(D!?7&XB.PI]"F5L<V4@>PIP<FEN="`B0%]<;B([
M"GT*?0IS=6(@:6YI=%]I;F,@>PIR97%U:7)E($-O;F9I9SL*<'5S:"!`24Y#
M+"!G<F5P(&1E9FEN960L(&UA<"`D0V]N9FEG.CI#;VYF:6=[)%]]+"!Q=R@*
M87)C:&QI8F5X<"!P<FEV;&EB97AP('-I=&5A<F-H97AP('-I=&5L:6)E>'`*
M=F5N9&]R87)C:&5X<"!V96YD;W)L:6)E>'`**3L*?0IP86-K86=E(&UA:6X[
M"G)E<75I<F4@4$%2.PIU;G-H:69T($!)3D,L(%PF4$%2.CIF:6YD7W!A<CL*
M4$%2+3YI;7!O<G0H0'!A<E]A<F=S*3L*9&EE('%Q6W!A<BYP;#H@0V%N)W0@
M;W!E;B!P97)L('-C<FEP="`B)'!R;V=N86UE(CH@3F\@<W5C:"!F:6QE(&]R
M(&1I<F5C=&]R>5QN70IU;FQE<W,@+64@)'!R;V=N86UE.PID;R`D<')O9VYA
M;64["D-/4D4Z.F5X:70H)#$I(&EF("@D0"`]?B]>7U1+7T58251?7"@H7&0K
M*5PI+RD["F1I92`D0"!I9B`D0#L*?3L*)#HZ7U]%4E)/4B`]("1`(&EF("1`
M.PI]"D-/4D4Z.F5X:70H)#$I(&EF("@D.CI?7T524D]2(#U^+UY?5$M?15A)
M5%]<*"A<9"LI7"DO*3L*9&EE("0Z.E]?15)23U(@:68@)#HZ7U]%4E)/4CL*
M,3L*7U]%3D1?7PH`<&5R;'AS:2YC`%]?14Y67U!!4E]#3$5!3E]?("`@("`@
M("`@("`@("`@``````$;`SL```#H````'/__@KP```50__^%#````03__X:,
M```!-/__AVP```&4__^(U````=#__XED```"`/__BE0```(\__^,]````GS_
M_XUL```"N/__C:P```+8__^.A````Q3__XZ,```#*/__D*0```-D__^0[```
M`WC__Y(4```#G/__F!P```/0__^8K````_S__YC<```$'/__F>P```1\__^A
M?```!-#__Z0,```%#/__I20```64__^\=```!=3__[SD```%^/__OAP```8T
M__^_A```!FS__[_L```&I/__O_0```:\````%``````!>E(``7@.`1L,#Z`!
M!PX`````%````!S__X0`````1@``````````````%``````!>E(``7@.`1L,
M#Z`!````````7````!S__X50````W`!&A@Z'#8@,B0N*"HL)C`B-!XX&CP5&
M#L`"`I@*S\[-S,O*R<C'Q@Z@`4(+7`K/SLW,R\K)R,?&#J`!0@M."L_.S<S+
MRLG(Q\8.H`%""P``````.````'S__X70```!9@!&A@Z'#8@,B0N*"HL)C`B-
M!XX&CP5&#N`#=`K/SLW,R\K)R,?&#J`!0@L`````+````+C__X;\````C@!&
MB@J+"8P(C0>.!H\%1@[8`P)Z"L_.S<S+R@Z@`4(+````.````.C__X=<````
M\`!&APV(#(D+B@J+"8P(C0>.!H\%1@[((@+4"L_.S<S+RLG(QPZ@`4(+````
M````/````23__X@0```"G`!&A@Z'#8@,B0N*"HL)C`B-!XX&CP5&#M@"`P%D
M"L_.S<S+RLG(Q\8.H`%""P```````#@```%D__^*<````'@`1H8.APV(#(D+
MB@J+"8P(C0>.!H\%1@[(`@)JS\[-S,O*R<C'Q@Z@`0```````!P```&@__^*
MK````#P`3(X&CP5&#L`"9,_.#J`!````.````<#__XK,````U`!&A@Z'#8@,
MB0N*"HL)C`B-!XX&CP5&#MA"`K@*S\[-S,O*R<C'Q@Z@`4(+````$````?S_
M_XMH````!@`````````X```"$/__BUP```(6`$:&#H<-B`R)"XH*BPF,"(T'
MC@:/!48.\","=@K/SLW,R\K)R,?&#J`!0@L````0```"3/__C3@```!$````
M`````"````)@__^-;````28``LJ.!H\%1@[``E+/S@Z@`0```````#````*$
M__^.<```!@(`1HH*BPF,"(T'C@:/!48.\`(#!:X*S\[-S,O*#J`!0@L`````
M```H```"N/__E$0```"0`$:+"8P(C0>.!H\%1@[0`G8*S\[-S,L.H`%""P``
M`!P```+D__^4J````"X`1HX&CP5&#L`"8,_.#J`!````7````P3__Y2X```!
M"@!&A@Z'#8@,B0N*"HL)C`B-!XX&CP5&#N`"`EH*S\[-S,O*R<C'Q@Z@`4(+
M6@K/SLW,R\K)R,?&#J`!1@L"=@K/SLW,R\K)R,?&#J`!1@L`````4````V3_
M_Y5H```'B@!,A@Z'#8@,B0N*"HL)C`B-!XX&CP5&#J"%`@,".@K/SLW,R\K)
MR,?&#J`!0@L#`OP*S\[-S,O*R<C'Q@Z@`48+````````.````[C__YRD```"
MB@!&APV(#(D+B@J+"8P(C0>.!H\%1@[0`@,!U@K/SLW,R\K)R,<.H`%""P``
M````0````_3__Y[X```!$@!&B0N*"HL)C`B-!XX&CP5&#M`"`GX*S\[-S,O*
MR0Z@`4(+`FH*S\[-S,O*R0Z@`48+``````!````$./__?60```)0`$:&#H<-
MB`R)"XH*BPF,"(T'C@:/!48.Z`(#`:@*S\[-S,O*R<C'Q@Z@`4(+````````
M`````#P```1\__^?B```%TH`2H8.APV(#(D+B@J+"8P(C0>.!H\%1@[0!P,7
M,@K/SLW,R\K)R,?&#J`!0@L````````@```$O/__MI@```!L`$J.!H\%1@[`
M`@):S\X.H`$````````X```$X/__MN0```$T`$R&#H<-B`R)"XH*BPF,"(T'
MC@:/!5X.P`("K@K/SLW,R\K)R,?&#J`!0@L````T```%'/__M^````%B`$:(
M#(D+B@J+"8P(C0>.!H\%;`[``@+""L_.S<S+RLG(#J`!1@L``````#0```54
M__^Y$````&0`1H<-B`R)"XH*BPF,"(T'C@:/!48.P`("5L_.S<S+RLG(QPZ@
M`0``````%```!8S__[E``````@``````````````$```!:3__[DP````#```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````#__________P``````````__________\`````````````
M```````!`````````M<``````````0````````+G``````````$````````"
M]P`````````,````````&8``````````#0```````%YP`````&___O4`````
M```"D``````````%````````#'``````````!@````````-P``````````H`
M```````$@``````````+`````````!@`````````%0``````````````````
M``,```````"Q\``````````"````````!2@`````````%``````````'````
M`````!<````````46``````````'````````$C``````````"`````````(H
M``````````D`````````&``````````>``````````@`````;___^P`````(
M```!`````&____X````````1L`````!O____``````````(`````;___\```
M`````!#P`````&____D`````````#```````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````L"``````````````````````````````&?H`
M```````:&@```````!HZ````````&EH````````:>@```````!J:````````
M&KH````````:V@```````!KZ````````&QH````````;.@```````!M:````
M````&WH````````;F@```````!NZ````````&]H````````;^@```````!P:
M````````'#H````````<6@```````!QZ````````')H````````<N@``````
M`!S:````````'/H````````=&@```````!TZ````````'5H````````=>@``
M`````!V:````````';H````````=V@```````!WZ````````'AH````````>
M.@```````!Y:````````'GH````````>F@```````!ZZ````````'MH`````
M```>^@```````!\:````````'SH````````?6@```````!]Z````````'YH`
M```````?N@```````!_:````````'_H````````@&@```````"`Z````````
M(%H````````@>@```````"":````````(+H`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````(-``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````#`"/____\`````````````88H`
M``````!?````````````````````7Z````````!?I````````&%^````````
M7P8```````!AA@``````````````````86X```````!A=```````````````
M````89!'0T,Z("A$96)I86X@,3$N,BXP+3$V*2`Q,2XR+C```"YS:'-T<G1A
M8@`N:6YT97)P`"YN;W1E+F=N=2YB=6EL9"UI9``N;F]T92Y!0DDM=&%G`"YG
M;G4N:&%S:``N9'EN<WEM`"YD>6YS='(`+F=N=2YV97)S:6]N`"YG;G4N=F5R
M<VEO;E]R`"YR96QA+F1Y;@`N<F5L82YP;'0`+FEN:70`+G1E>'0`+F9I;FD`
M+G)O9&%T80`N96A?9G)A;65?:&1R`"YE:%]F<F%M90`N8W1O<G,`+F1T;W)S
M`"YD>6YA;6EC`"YG;W0`+F1A=&$`+F)S<P`N8V]M;65N=```````````````
M````````````````````````````````````````````````````````````
M``````````````````L````!``````````(````````".`````````(X````
M``````\````````````````````!```````````````3````!P`````````"
M`````````D@````````"2``````````D````````````````````!```````
M````````)@````<``````````@````````)L`````````FP`````````(```
M``````````````````0``````````````#1O___V``````````(````````"
MD`````````*0`````````.`````%```````````````(```````````````^
M````"P`````````"`````````W`````````#<`````````D`````!@````(`
M````````"``````````8````1@````,``````````@````````QP````````
M#'`````````$@`````````````````````$``````````````$YO____````
M``````(````````0\````````!#P`````````,`````%```````````````"
M``````````(```!;;____@`````````"````````$;`````````1L```````
M``"`````!@````(`````````"```````````````:@````0``````````@``
M`````!(P````````$C`````````"*`````4```````````````@`````````
M&````'0````$`````````$(````````46````````!18````````!2@````%
M````%0`````````(`````````!@```!^`````0`````````&````````&8``
M```````9@`````````!,````````````````````!```````````````>0``
M``$`````````!@```````!G,````````&<P````````'````````````````
M``````0`````````(````(0````!``````````8````````@T````````"#0
M````````/:`````````````````````(``````````````"*`````0``````
M```&````````7G````````!><``````````T````````````````````!```
M````````````D`````$``````````@```````%ZD````````7J0````````_
M;@````````````````````0``````````````)@````!``````````(`````
M``">%````````)X4`````````.P````````````````````$````````````
M``"F`````0`````````"````````GP````````"?``````````7H````````
M````````````"```````````````L`````$``````````P```````+``````
M````L```````````$`````````````````````@``````````````+<````!
M``````````,```````"P$````````+`0`````````!``````````````````
M```(``````````````"^````!@`````````#````````L"````````"P(```
M``````'0````!@``````````````"``````````0````QP````$`````````
M`P```````+'P````````L?`````````",`````````````````````@`````
M````"````,P````!``````````,```````#``````````,```````````(``
M```````````````````(``````````````#2````"``````````#````````
MP(````````#`@````````!`P````````````````````"```````````````
MUP````$`````````,```````````````````P(``````````'P``````````
M``````````$``````````0````$````#````````````````````````````
C`,"?`````````.`````````````````````!````````````
